@@ -322,16 +322,16 @@ public class CDF2CDFML implements CDFConstants {
     private static void printHeader () {
         out.println ("<?xml version=\"1.0\" standalone=\"no\"?>");
         if (mode.equalsIgnoreCase("dtd")) { 
-            out.println ("<!-- Change \"https://cdf.gsfc.nasa.gov/"+
+            out.println ("<!-- Change \"http://cdf.gsfc.nasa.gov/"+
                          "cdf.dtd\" to \"cdf.dtd\" if you want to");
             out.println ("     use a local version of cdf.dtd. -->");
             out.println ("<!DOCTYPE CDF SYSTEM \""+
                          "http://cdf.gsfc.nasa.gov/cdf.dtd\">");
         } 
         else if (mode.equalsIgnoreCase("xsd")) {
-            out.print ("<CDF xmlns=\"https://cdf.gsfc.nasa.gov\"");
+            out.print ("<CDF xmlns=\"http://cdf.gsfc.nasa.gov\"");
             if (choice) {
-              out.print(" xsi:schemaLocation=\"https://cdf.gsfc.nasa.gov/cdf.xsd\"");
+              out.print(" xsi:schemaLocation=\"http://cdf.gsfc.nasa.gov/cdf.xsd\"");
               out.print(" xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" xmlns:xsd=\"http://www.w3.org/2001/XMLSchema\"");
             }
             out.println (" name=\""+inFile+"\">");
@@ -1306,7 +1306,7 @@ Object newAttrName = GetMyCDFData.replaceStringNameToXML ((Object)attrName);
                      out.println ("</parameter> ");
                  }
                  else {
-out.println ("<attribute name=\""+newAttrName+"\">");
+out.println ("<attribute name=\""+newAttrName+"\"></attribute>");
 /*
                    if (attrName.indexOf("\"") < 0)
                      out.println ("<attribute name=\""+attrName+"\"/>");
