@@ -27,6 +27,7 @@ public class CDFCompare extends JFrame
 /** The FileChooser for the file selection. */
     JFileChooser fileChooser = new JFileChooser();
 
+    JPanel panelx = new JPanel(new BorderLayout(), true);
 /** The panel for text fields and selectable buttons which goes to dialog's
     north portion. */
     JPanel panel1 = new JPanel(new GridBagLayout(), true);
@@ -353,7 +354,8 @@ public class CDFCompare extends JFrame
 //      OUTF.setFont(boldFont);
 //      outf.setFont(boldFont);
 
-        dialog.getContentPane().add(panel1,BorderLayout.NORTH);
+/*        dialog.getContentPane().add(panel1,BorderLayout.NORTH); */
+        panelx.add(panel1, BorderLayout.NORTH);
 
         // Panel 2
 
@@ -468,7 +470,8 @@ public class CDFCompare extends JFrame
         abc.setToolTipText("Display the current version");
 //	bac.addItemListener(this);
 
-        dialog.getContentPane().add(panel2,BorderLayout.CENTER);
+/*        dialog.getContentPane().add(panel2,BorderLayout.CENTER);*/
+        panelx.add(panel2, BorderLayout.CENTER);
 
         // Panel 3 (buttons and text area)
 
@@ -499,8 +502,11 @@ public class CDFCompare extends JFrame
                 }
         };
         scroller.getViewport().add(info);
-        panel3.add(scroller, BorderLayout.SOUTH);
-        dialog.getContentPane().add(panel3, BorderLayout.SOUTH);
+/*        panel3.add(scroller, BorderLayout.SOUTH); */
+        panelx.add(panel3, BorderLayout.SOUTH);
+
+        dialog.getContentPane().add(panelx, BorderLayout.NORTH);
+        dialog.getContentPane().add(scroller, BorderLayout.CENTER);
     }
 
 /** Implement the run method for Runabout interface.
