@@ -27,6 +27,7 @@ public class CDFDir extends JFrame
 
 /** The FileChooser for the file selection. */
     JFileChooser fileChooser = new JFileChooser();
+    JPanel panelx = new JPanel(new BorderLayout(), true);
 
 /** The panel for selectable buttons which goes to dialog's north portion. */
     JPanel panel1 = new JPanel(new GridBagLayout(), true);
@@ -155,6 +156,11 @@ public class CDFDir extends JFrame
                  help = help.substring(0, sepindx);
              } 
              helpolh = help + separator + "cdfdirj.olh";
+           } else {
+	     help = System.getProperty("CDF_HELP");
+             if (help != null && help.length() > 0) {
+               helpolh = help + separator + "cdfdirj.olh";
+             }
            }
 	}
         dialog = new JDialog(this, modal);
@@ -226,7 +232,8 @@ public class CDFDir extends JFrame
         slt.setToolTipText("Use the file chooser to select a CDF");
         CDF.setFont(boldFont);
         cdf.setFont(boldFont);
-	dialog.getContentPane().add(panel1,BorderLayout.CENTER);
+//	dialog.getContentPane().add(panel1,BorderLayout.CENTER);
+	panelx.add(panel1,BorderLayout.CENTER);
 	
         // Panel 2 (buttons and text area)
 
@@ -257,10 +264,15 @@ public class CDFDir extends JFrame
                 }
         };
         scroller.getViewport().add(info);
-        panel2.add(scroller, BorderLayout.SOUTH);
+//        panel2.add(scroller, BorderLayout.SOUTH);
   	info.setVisible(true);
 
-  	dialog.getContentPane().add(panel2, BorderLayout.SOUTH);
+//  	dialog.getContentPane().add(panel2, BorderLayout.SOUTH);
+  	panelx.add(panel2, BorderLayout.SOUTH);
+
+        dialog.getContentPane().add(panelx, BorderLayout.NORTH);
+        dialog.getContentPane().add(scroller, BorderLayout.CENTER);
+
     }
 
 /** Implement the run method for Runabout interface.
