@@ -55,6 +55,8 @@ public class CDFDump extends JFrame
     JCheckBox crc = new JCheckBox("Column-to-Row");
 /** "Detect" checkbox. */
     JCheckBox dtc = new JCheckBox("Detect");
+/** A label of "Style:" for the radio button group zmode. */
+    JLabel STYLE = new JLabel("Style: ");
 
 /** A label of "Dump:" for the radio button zmode. */
     JLabel DUMP = new JLabel("Dump:  ");
@@ -69,6 +71,14 @@ public class CDFDump extends JFrame
 /** A radio button panel for Dump. */
     JPanel dumpPanel = new JPanel(true);
 
+/** A group radio buttons for Style. */
+    ButtonGroup style = new ButtonGroup();
+/** A group radio buttons for style. */
+    JRadioButton style0 = new JRadioButton("iso8601");
+    JRadioButton style1 = new JRadioButton("iso8601/z");
+/** A radio button panel for style. */
+    JPanel stylePanel = new JPanel(true);
+
 /** A label of "Precision:" for the text field Precision. */
     JLabel PRECISION = new JLabel("Significant #: ");
 /** Text field for entering optional variable names. */
@@ -77,12 +87,12 @@ public class CDFDump extends JFrame
 /** A label of "Vars:" for the text field vars. */
     JLabel VARS = new JLabel("Variables: ");
 /** Text field for entering optional variable names. */
-    JTextField vars = new JTextField("",40);
+    JTextField vars = new JTextField("",20);
 
 /** A label of "Rec Ranges:" for the text field vars. */
     JLabel RECS = new JLabel("Rec Ranges: ");
 /** Text field for entering optional variable names. */
-    JTextField recs = new JTextField("",40);
+    JTextField recs = new JTextField("",20);
 
 /** "Enter" button. */
     JButton entrb = new JButton(" Enter ");
@@ -137,6 +147,7 @@ public class CDFDump extends JFrame
     String strvars = "";
     String strrecs = "";
     String strprec = "";
+    String strsty = "0";
     String yyy;
     String zzz;
 
@@ -301,6 +312,23 @@ public class CDFDump extends JFrame
         dumpPanel.add(dump3);
         dumpPanel.add(dump4);
 
+        // Initialize the Style choice.
+
+        StyleListener StyleListener = new StyleListener();
+        style0.setActionCommand("0");
+        style1.setActionCommand("1");
+        style0.addActionListener(StyleListener);
+        style1.addActionListener(StyleListener);
+        style0.setSelected(true);
+        style.add(style0);
+        style.add(style1);
+        style0.setToolTipText("Use ISO8601 form for date/time display");
+        style1.setToolTipText("Use ISO8601 with z form for date/time display");
+
+        stylePanel.setLayout(new FlowLayout());
+        stylePanel.add(style0);
+        stylePanel.add(style1);
+
         // Panel 1
 
 	makeJButton(panel1, Box.createRigidArea(vpad5), 0, 0, 1, 1, 0.0, 0.0);
@@ -339,30 +367,36 @@ public class CDFDump extends JFrame
 
         makeJButton(panel2n, Box.createRigidArea(vpad5), 0, 0, 1, 1, 0.0, 0.0);
 	makeJButton(panel2n, abc, 0, 1, 1, 1, 0.0, 0.0);
-        makeJButton(panel2n, Box.createRigidArea(hpad40), 1, 1, 1, 1, 0.0, 0.0);
+//        makeJButton(panel2n, Box.createRigidArea(hpad5), 1, 1, 1, 1, 0.0, 0.0);
         makeJButton(panel2n, qec, 2, 1, 1, 1, 0.0, 0.0);
-        makeJButton(panel2n, Box.createRigidArea(hpad40), 3, 1, 1, 1, 0.0, 0.0);
+//        makeJButton(panel2n, Box.createRigidArea(hpad5), 3, 1, 1, 1, 0.0, 0.0);
 	makeJButton(panel2n, ufc, 4, 1, 1, 1, 0.0, 0.0);
-        makeJButton(panel2n, Box.createRigidArea(hpad40), 5, 1, 1, 1, 0.0, 0.0);
+//        makeJButton(panel2n, Box.createRigidArea(hpad5), 5, 1, 1, 1, 0.0, 0.0);
 	makeJButton(panel2n, crc, 6, 1, 1, 1, 0.0, 0.0);
-        makeJButton(panel2n, Box.createRigidArea(hpad40), 7, 1, 1, 1, 0.0, 0.0);
+//        makeJButton(panel2n, Box.createRigidArea(hpad5), 7, 1, 1, 1, 0.0, 0.0);
 
+//        makeJButton(panel2n, Box.createRigidArea(vpad5), 0, 2, 1, 1, 0.0, 0.0);
         makeJButton(panel2n, dtc, 0, 2, 1, 1, 1.0, 1.0);
-	makeJButton(panel2n, Box.createRigidArea(hpad40), 1, 2, 1, 1, 0.0, 0.0);
+//	makeJButton(panel2n, Box.createRigidArea(hpad5), 1, 2, 1, 1, 0.0, 0.0);
 
-        makeJButton(panel2n, Box.createRigidArea(vpad5), 0, 3, 1, 1, 0.0, 0.0);
-        makeJButton(panel2n, PRECISION, 2, 3, 1, 1, 1.0, 1.0);
-        makeJButton(panel2n, precision, 3, 3, 1, 1, 1.0, 1.0);
-	makeJButton(panel2n, Box.createRigidArea(hpad40), 4, 3, 1, 1, 0.0, 0.0);
-        makeJButton(panel2n, tpanel1, 6, 3, 1, 1, 0.0, 0.0);
-        makeJButton(panel2n, Box.createRigidArea(vpad5), 7, 3, 1, 1, 0.0, 0.0);
+//        makeJButton(panel2n, Box.createRigidArea(vpad5), 0, 3, 1, 1, 0.0, 0.0);
+        makeJButton(panel2n, STYLE, 0, 3, 1, 1, 1.0, 1.0);
+        makeJButton(panel2n, stylePanel, 1, 3, 1, 1, 1.0, 1.0);
+//	makeJButton(panel2n, Box.createRigidArea(hpad5), 2, 3, 1, 1, 0.0, 0.0);
+
+//        makeJButton(panel2n, Box.createRigidArea(vpad5), 0, 4, 1, 1, 0.0, 0.0);
+        makeJButton(panel2n, PRECISION, 0, 4, 1, 1, 1.0, 1.0);
+        makeJButton(panel2n, precision, 1, 4, 1, 1, 1.0, 1.0);
+	makeJButton(panel2n, Box.createRigidArea(hpad5), 2, 4, 1, 1, 0.0, 0.0);
+        makeJButton(panel2n, tpanel1, 3, 4, 1, 1, 0.0, 0.0);
+        makeJButton(panel2n, Box.createRigidArea(vpad5), 4, 4, 1, 1, 0.0, 0.0);
 
         makeJButton(panel2s, Box.createRigidArea(vpad5), 0, 0, 1, 1, 0.0, 0.0);
         makeJButton(panel2s, VARS, 0, 1, 1, 1, 1.0, 1.0);
         makeJButton(panel2s, vars, 1, 1, 2, 1, 1.0, 1.0);
         makeJButton(panel2s, RECS, 0, 2, 1, 1, 1.0, 1.0);
         makeJButton(panel2s, recs, 1, 2, 2, 1, 1.0, 1.0);
-        makeJButton(panel2s, Box.createRigidArea(vpad20), 0, 3, 1, 1, 1.0, 1.0);
+        makeJButton(panel2s, Box.createRigidArea(vpad20), 0, 4, 1, 1, 1.0, 1.0);
 
         panel2.add(panel2n, BorderLayout.NORTH);
         panel2.add(panel2s, BorderLayout.SOUTH);
@@ -424,7 +458,7 @@ public class CDFDump extends JFrame
                 static final long serialVersionUID = 1L;
 
                 public Dimension getPreferredSize() {
-                   return new Dimension(80, 160);
+                   return new Dimension(80, 80);
                 }
                 public float getAlignmentX() {
                    return LEFT_ALIGNMENT;
@@ -577,8 +611,10 @@ public class CDFDump extends JFrame
                     strprec = new StringBuffer("-significant ").append(precValue).toString();
                 }
 		commandX = command + strdt + struf + strqe + "-dump " + strdp + " " + 
-                           xxx + yyy + " " + zzz + " " + strprec + " " + strcr +
-                           cdfDelimiter + cdfspec + cdfDelimiter;
+                           xxx + yyy + " " + zzz + " " + 
+                           (strsty.equals("1")?"-ziso8601 ":"") +
+                           strprec +
+                           " " + strcr + cdfDelimiter + cdfspec + cdfDelimiter;
 
                 String OS = System.getProperty("os.name").toLowerCase();
                 if (OS.indexOf("windows") != -1) {
@@ -652,6 +688,15 @@ public class CDFDump extends JFrame
         }
     }
 
+/** Action for radio buttons for Style
+ */
+
+    class StyleListener implements ActionListener {
+        public void actionPerformed(ActionEvent e) {
+           strsty = e.getActionCommand();
+        }
+    }
+
 /** Action for checkboxs selection
  */
 
