@@ -191,6 +191,7 @@ public class CDFEdit extends JFrame implements ActionListener, ItemListener,
         buildMenu();
 	buildGUIs();
 
+        JPanel panelx = new JPanel(new BorderLayout(), true);
 	// Panel 1
         JPanel panel1 = new JPanel(new GridLayout(5, 1), true);
 
@@ -255,7 +256,8 @@ public class CDFEdit extends JFrame implements ActionListener, ItemListener,
 
         panel1.add(panel14);
 
-        dialog.getContentPane().add(panel1,BorderLayout.CENTER);
+//        dialog.getContentPane().add(panel1,BorderLayout.CENTER);
+        panelx.add(panel1,BorderLayout.CENTER);
 
         // Panel 2 (buttons and text area)
 
@@ -269,8 +271,15 @@ public class CDFEdit extends JFrame implements ActionListener, ItemListener,
         panel21.add(Box.createRigidArea(new Dimension(10,1)));
         panel2.add(panel21, BorderLayout.NORTH);
 
+//        panel2.add(scroller, BorderLayout.SOUTH);
         panel2.add(scroller, BorderLayout.SOUTH);
-        dialog.getContentPane().add(panel2, BorderLayout.SOUTH);
+
+//        dialog.getContentPane().add(panel2, BorderLayout.SOUTH);
+        panelx.add(panel2, BorderLayout.SOUTH);
+
+        dialog.getContentPane().add(panelx, BorderLayout.NORTH);
+        dialog.getContentPane().add(scroller, BorderLayout.CENTER);
+
     }
 
 /** Build the GUIs for the main dialog
@@ -826,8 +835,16 @@ public class CDFEdit extends JFrame implements ActionListener, ItemListener,
 	String osVersion = System.getProperty("os.version");
 	String javaVersion = System.getProperty("java.version");
         if (osName.toLowerCase().indexOf("windows") != -1) {
-          if (osVersion.compareTo("5.0") >= 0 &&   // Windows 2000 and beyond...
-	      javaVersion.compareTo("1.4") >= 0) { // Java 1.4 
+          int thisOS = new Integer(osVersion.substring(0, osVersion.indexOf("."))).intValue();
+          int inIndex = javaVersion.indexOf(".");
+          String subJavaVersion = javaVersion.substring(inIndex+1);
+          int thisMajorV = new Integer(javaVersion.substring(0, inIndex)).intValue();
+          int thisMinorV = new Integer(subJavaVersion.substring(0, subJavaVersion.indexOf("."))).intValue();
+          int thisJava = (thisMinorV<10?thisMajorV*10+thisMinorV:thisMajorV*100+thisMinorV);
+//        if (osVersion.compareTo("5.0") >= 0 &&   // Windows 2000 and beyond...
+//            javaVersion.compareTo("1.4") >= 0) { // Java 1.4
+          if (thisOS >= 5 &&   // Windows 2000 and beyond...
+               thisJava >= 14) { // Java 1.4
             try {
 	      Runtime runtime = Runtime.getRuntime();
               Process process = runtime.exec("cmd /c assoc .cdf");
