@@ -89,7 +89,7 @@ public class CDFExport extends JFrame implements ActionListener, ItemListener,
     protected int COLUMNS = 9;
     protected long majority = 0;
     protected long encoding = 0;
-    protected int epoch = 0;
+    protected int epoch = 4;
     protected long format = 1;
     protected int compressionType = -1;
     protected int compressionLevel = 0;
@@ -227,6 +227,8 @@ public class CDFExport extends JFrame implements ActionListener, ItemListener,
 	cdfexport.getContentPane().setLayout(new BorderLayout()); 
         addMenu();
 
+	JPanel panelx = new JPanel(new BorderLayout(), true);
+
 	// Panel 1
 
 	slt1 = new JButton("Select");
@@ -249,7 +251,8 @@ public class CDFExport extends JFrame implements ActionListener, ItemListener,
 	cdf1.setToolTipText("Enter the source CDF file (without extension) for export");
 	slt1.setToolTipText("Use the file chooser to select the source CDF");
 
-        cdfexport.getContentPane().add(panel1,BorderLayout.NORTH);
+//        cdfexport.getContentPane().add(panel1,BorderLayout.NORTH);
+        panelx.add(panel1,BorderLayout.NORTH);
 
         // Panel 2
 
@@ -370,7 +373,8 @@ public class CDFExport extends JFrame implements ActionListener, ItemListener,
 	panel2.add(abc); 
 //        panel2.add(Box.createRigidArea(vpad5));
 
-        cdfexport.getContentPane().add(panel2,BorderLayout.CENTER);
+//        cdfexport.getContentPane().add(panel2,BorderLayout.CENTER);
+        panelx.add(panel2,BorderLayout.CENTER);
 
         // Panel 3 (buttons and text area)
 
@@ -410,8 +414,13 @@ public class CDFExport extends JFrame implements ActionListener, ItemListener,
                 }
         };
         scroller.getViewport().add(info);
-        panel3.add(scroller, BorderLayout.SOUTH);
-        cdfexport.getContentPane().add(panel3, BorderLayout.SOUTH);
+//        panel3.add(scroller, BorderLayout.SOUTH);
+//        cdfexport.getContentPane().add(panel3, BorderLayout.SOUTH);
+        panelx.add(panel3, BorderLayout.SOUTH);
+
+        cdfexport.getContentPane().add(panelx, BorderLayout.NORTH);
+        cdfexport.getContentPane().add(scroller, BorderLayout.CENTER);
+
     }
 
 /** Set up the menubar and items
@@ -843,7 +852,7 @@ public class CDFExport extends JFrame implements ActionListener, ItemListener,
        COLUMNS = 9;
        majority = 0;
        encoding = 0;
-       epoch = 0;
+       epoch = 4;
        format = 1;
        compressionType = -1;
        compressionLevel = 0;
@@ -1023,8 +1032,16 @@ public class CDFExport extends JFrame implements ActionListener, ItemListener,
         String osVersion = System.getProperty("os.version");
 	String javaVersion = System.getProperty("java.version");
         if (osName.toLowerCase().indexOf("windows") != -1) {
-          if (osVersion.compareTo("5.0") >= 0 &&   // Windows 2000 and beyond...
-              javaVersion.compareTo("1.4") >= 0) { // Java 1.4 
+          int thisOS = new Integer(osVersion.substring(0, osVersion.indexOf("."))).intValue();
+          int inIndex = javaVersion.indexOf(".");
+          String subJavaVersion = javaVersion.substring(inIndex+1);
+          int thisMajorV = new Integer(javaVersion.substring(0, inIndex)).intValue();
+          int thisMinorV = new Integer(subJavaVersion.substring(0, subJavaVersion.indexOf("."))).intValue();
+          int thisJava = (thisMinorV<10?thisMajorV*10+thisMinorV:thisMajorV*100+thisMinorV);
+//        if (osVersion.compareTo("5.0") >= 0 &&   // Windows 2000 and beyond...
+//            javaVersion.compareTo("1.4") >= 0) { // Java 1.4
+          if (thisOS >= 5 &&   // Windows 2000 and beyond...
+               thisJava >= 14) { // Java 1.4
             try {
               Runtime runtime = Runtime.getRuntime();
               Process process = runtime.exec("cmd /c assoc .cdf");
