@@ -23,6 +23,7 @@ public class CDFInquire extends JFrame
     JFrame parentFrame;
 /** dialog for user interface. */
     JDialog dialog;
+    JPanel panelx = new JPanel(new BorderLayout(), true);
 
 /** The panel for selectable buttons which goes to dialog's north portion. */
     JPanel panel1 = new JPanel(new GridBagLayout(), true);
@@ -182,7 +183,8 @@ public class CDFInquire extends JFrame
         pgc.setToolTipText("Select to display the output one page at a time -- not avaiable for Java");
         abc.addItemListener(this);
         abc.setToolTipText("Display the current version");
-	dialog.getContentPane().add(panel1,BorderLayout.NORTH);
+//	dialog.getContentPane().add(panel1,BorderLayout.NORTH);
+	panelx.add(panel1,BorderLayout.NORTH);
 	
 
         // Panel 2
@@ -192,7 +194,6 @@ public class CDFInquire extends JFrame
         panel21.add(quitb);
         panel2.add(panel21, BorderLayout.NORTH);
         panel2.add(Box.createRigidArea(vpad20),BorderLayout.SOUTH);
-	dialog.getContentPane().add(panel2,BorderLayout.CENTER);
 
         // Listen for events on buttons
         entrb.addActionListener(this);
@@ -216,9 +217,13 @@ public class CDFInquire extends JFrame
         };
 
 	scroller.getViewport().add(info);
-        panel3.add(scroller, BorderLayout.CENTER);
         info.setVisible(true);
-        dialog.getContentPane().add(panel3, BorderLayout.SOUTH);
+
+//	dialog.getContentPane().add(panel2,BorderLayout.CENTER);
+	panelx.add(panel2,BorderLayout.SOUTH);
+//        dialog.getContentPane().add(panel3, BorderLayout.SOUTH);
+        dialog.getContentPane().add(panelx, BorderLayout.NORTH);
+        dialog.getContentPane().add(scroller, BorderLayout.CENTER);
 
     }
 
