@@ -156,8 +156,16 @@ public class CDFToolsDriver extends JFrame implements ActionListener {
 	if (osName.toLowerCase().indexOf("windows") != -1) {
 	  String osVersion = System.getProperty("os.version");
 	  String javaVersion = System.getProperty("java.version");
-          if (osVersion.compareTo("5.0") >= 0 &&   // Windows 2000 and beyond...
-              javaVersion.compareTo("1.4") >= 0) { // Java 1.4
+	  int thisOS = new Integer(osVersion.substring(0, osVersion.indexOf("."))).intValue();
+	  int inIndex = javaVersion.indexOf(".");
+	  String subJavaVersion = javaVersion.substring(inIndex+1);
+	  int thisMajorV = new Integer(javaVersion.substring(0, inIndex)).intValue();
+	  int thisMinorV = new Integer(subJavaVersion.substring(0, subJavaVersion.indexOf("."))).intValue();
+	  int thisJava = (thisMinorV<10?thisMajorV*10+thisMinorV:thisMajorV*100+thisMinorV);
+//        if (osVersion.compareTo("5.0") >= 0 &&   // Windows 2000 and beyond...
+//            javaVersion.compareTo("1.4") >= 0) { // Java 1.4
+          if (thisOS >= 5 &&   // Windows 2000 and beyond...
+               thisJava >= 14) { // Java 1.4
 	    try {
 	      process = runtime.exec("cmd /c assoc .cdf");
 	      inStream = new BufferedReader(new
