@@ -464,13 +464,13 @@ public class EditvVarEntryTableScrollPane extends JScrollPane implements CDFCons
                       StringBuffer tmpStr = new StringBuffer();
                       for (int i = 0; i < ((double[])value).length; i++) {
                         if (i > 0) tmpStr.append(", ");
-                        String tmp = Epoch.encode(((double[])value)[i]);
+                        String tmp = Epoch.encode4(((double[])value)[i]);
                         tmpStr.append(tmp);
                       }
 //                      tmpStr.setLength(tmpStr.length()-2);
                       dataObject[jj][2] = tmpStr.toString();
                     } else {
-                      dataObject[jj][2] = Epoch.encode(((Double)value).doubleValue());
+                      dataObject[jj][2] = Epoch.encode4(((Double)value).doubleValue());
 		    }
                   } else if (dataType == CDF_EPOCH16) {
                     if (value.getClass().getName().indexOf('[') == 0) { // an array
@@ -480,7 +480,7 @@ public class EditvVarEntryTableScrollPane extends JScrollPane implements CDFCons
                         if (i > 0) tmpStr.append(", ");
 			aaa[0] = ((double[])value)[i];
 			aaa[1] = ((double[])value)[i+1];
-                        String tmp = Epoch16.encode(aaa);
+                        String tmp = Epoch16.encode4(aaa);
                         tmpStr.append(tmp);
                       }
 //                      tmpStr.setLength(tmpStr.length()-2);
@@ -498,8 +498,18 @@ public class EditvVarEntryTableScrollPane extends JScrollPane implements CDFCons
                       dataObject[jj][2] = tmpStr.toString();
                     } else 
                       dataObject[jj][2] = CDFTT2000.toUTCstring(((Long)value).longValue());
-                  } else 
-                    dataObject[jj][2] = CDFUtils.getStringData(value, ",");
+                  } else {
+                    if (dataType == CDF_REAL4 || dataType == CDF_REAL8 ||
+                        dataType == CDF_FLOAT || dataType == CDF_DOUBLE) {
+                      String format;
+                      try {
+                        format = (String) var.getEntryData("FORMAT");
+                      } catch (CDFException ce) { format = null; }
+                      dataObject[jj][2] = CDFUtils.getStringFloatingData (value, format, ", ").trim();
+                    } else
+                      dataObject[jj][2] = CDFUtils.getStringData(value, ",");
+                  }
+//                    dataObject[jj][2] = CDFUtils.getStringData(value, ",");
                 }
               }
             }
