@@ -44,11 +44,12 @@ public class SkeletonTable extends JFrame
     JPanel tpanel1 = new JPanel(new BorderLayout(), true);
     JPanel tpanel2 = new JPanel(new BorderLayout(), true);
     JPanel tpanel3 = new JPanel(new BorderLayout(), true);
+    JPanel tpanel4 = new JPanel(new BorderLayout(), true);
 
 /** "Page Output" checkbox. */
     JCheckBox pgc = new JCheckBox("Page Output", false);
 /** "Use Format" checkbox. */
-    JCheckBox ufc = new JCheckBox("Use Format",true);
+    JCheckBox ufc = new JCheckBox("Use Format", false);
 /** "Report Info's" checkbox. */
     JCheckBox ric = new JCheckBox("Report Info's");
     int ricX = 0;
@@ -94,6 +95,17 @@ public class SkeletonTable extends JFrame
 /** A radio button panel for style. */
     JPanel stylePanel = new JPanel(true);
 
+/** A group radio buttons for AdvFormat. */
+    ButtonGroup newformat = new ButtonGroup();
+/** A group radio buttons for newformat. */
+    JRadioButton newformat0 = new JRadioButton("best");
+    JRadioButton newformat1 = new JRadioButton("no");
+    JRadioButton newformat2 = new JRadioButton("metaonly");
+    JRadioButton newformat3 = new JRadioButton("dataonly");
+    JRadioButton newformat4 = new JRadioButton("all");
+/** A radio button panel for newformat. */
+    JPanel newformatPanel = new JPanel(true);
+
 /** A group radio buttons for Values. */
     ButtonGroup values = new ButtonGroup();
 /** A group radio buttons for Values. */
@@ -140,6 +152,8 @@ public class SkeletonTable extends JFrame
     JLabel ZMODE = new JLabel("zMode: ");
 /** A label of "Style:" for the radio button group zmode. */
     JLabel STYLE = new JLabel("Style: ");
+/** A label of "AdvFormat::" for the radio button group zmode. */
+    JLabel NEWFORMAT = new JLabel("AdvFormat: ");
 /** A label of "Values:" for the radio button group values. */
     JLabel VALUES = new JLabel("Values: ");
 
@@ -180,7 +194,8 @@ public class SkeletonTable extends JFrame
     String strzz = " ";
     String strzm = "";
     String strsty = "";
-    String report, Zmode, caches, temp, vars, estyle;
+    String strnfm = "";
+    String report, Zmode, caches, temp, vars, estyle, enewformat;
     String cdfspec = " ";
     String skltspec = "";
     String SKLTfile;
@@ -398,17 +413,17 @@ public class SkeletonTable extends JFrame
 	
         // Initialize the Style choice.
 
-        StyleListener StyleListener = new StyleListener();
+        StyleListener styleListener = new StyleListener();
         style0.setActionCommand("0");
         style1.setActionCommand("1");
         style2.setActionCommand("2");
         style3.setActionCommand("3");
         style4.setActionCommand("6");
-        style0.addActionListener(StyleListener);
-        style1.addActionListener(StyleListener);
-        style2.addActionListener(StyleListener);
-        style3.addActionListener(StyleListener);
-        style4.addActionListener(StyleListener);
+        style0.addActionListener(styleListener);
+        style1.addActionListener(styleListener);
+        style2.addActionListener(styleListener);
+        style3.addActionListener(styleListener);
+        style4.addActionListener(styleListener);
         style4.setSelected(true);
         style.add(style0);
         style.add(style1);
@@ -428,6 +443,38 @@ public class SkeletonTable extends JFrame
         stylePanel.add(style3);
         stylePanel.add(style4);
 	
+        // Initialize the AdvFormat choice.
+
+        AdvFormatListener newformatListener = new AdvFormatListener();
+        newformat0.setActionCommand("best");
+        newformat1.setActionCommand("no");
+        newformat2.setActionCommand("metaonly");
+        newformat3.setActionCommand("dataonly");
+        newformat4.setActionCommand("all");
+        newformat0.addActionListener(newformatListener);
+        newformat1.addActionListener(newformatListener);
+        newformat2.addActionListener(newformatListener);
+        newformat3.addActionListener(newformatListener);
+        newformat4.addActionListener(newformatListener);
+        newformat0.setSelected(true);
+        newformat.add(newformat0);
+        newformat.add(newformat1);
+        newformat.add(newformat2);
+        newformat.add(newformat3);
+        newformat.add(newformat4);
+        newformat4.setToolTipText("Use variable's FORMAT attribute to encode metadata and data value -- supersede the \"Use Format\" checkbox.");
+        newformat1.setToolTipText("Not to use variable's FORMAT attribute to encode metadata and data value -- supersede the \"Use Format\" checkbox.");
+        newformat2.setToolTipText("Use variable's FORMAT attribute to encode only metadata -- supersede the \"Use Format\" checkbox.");
+        newformat3.setToolTipText("Use variable's FORMAT attribute to encode variable data only -- supersede the \"Use Format\" checkbox.");
+        newformat0.setToolTipText("Use the best format, higher precision, either from variable's FORMAT attribute or C's %g to encode metadata and data -- supersede the \"Use Format\" checkbox.");
+
+        newformatPanel.setLayout(new FlowLayout());
+        newformatPanel.add(newformat0);
+        newformatPanel.add(newformat1);
+        newformatPanel.add(newformat2);
+        newformatPanel.add(newformat3);
+        newformatPanel.add(newformat4);
+	
 	// Initialize the values choice.
 
         ValuesListener valuesListener = new ValuesListener();
@@ -482,15 +529,20 @@ public class SkeletonTable extends JFrame
 	makeJButton(panel2n, tpanel1, 4, 3, 1, 1, 1.0, 1.0);
         tpanel2.add(STYLE,BorderLayout.WEST);
         tpanel2.add(stylePanel, BorderLayout.CENTER);
-        tpanel3.add(VALUES, BorderLayout.WEST); 
-        tpanel3.add(valuesPanel, BorderLayout.CENTER);
+
+        tpanel3.add(NEWFORMAT,BorderLayout.WEST);
+        tpanel3.add(newformatPanel, BorderLayout.CENTER);
+
+        tpanel4.add(VALUES, BorderLayout.WEST); 
+        tpanel4.add(valuesPanel, BorderLayout.CENTER);
 //        makeJButton(panel2c, Box.createRigidArea(hpad10), 1, 0, 1, 1, 1.0, 1.0);
 	makeJButton(panel2c, tpanel2, 0, 0, 1, 1, 1.0, 1.0);
-        makeJButton(panel2c, Box.createRigidArea(vpad10), 0, 1, 1, 1, 1.0, 1.0);
+        makeJButton(panel2c, Box.createRigidArea(vpad10), 1, 0, 1, 1, 1.0, 1.0);
+	makeJButton(panel2c, tpanel4, 2, 0, 1, 1, 1.0, 1.0);
+	makeJButton(panel2c, Box.createRigidArea(vpad10), 3, 0, 1, 1, 1.0, 1.0);
+        makeJButton(panel2c, tpanel3, 0, 1, 1, 1, 1.0, 1.0);
 
-	makeJButton(panel2c, tpanel3, 1, 0, 1, 1, 1.0, 1.0);
-	makeJButton(panel2c, Box.createRigidArea(vpad10), 0, 1, 1, 1, 1.0, 1.0);
-        makeJButton(panel2c, Box.createRigidArea(vpad10), 0, 1, 1, 1, 1.0, 1.0);
+//        makeJButton(panel2c, Box.createRigidArea(vpad10), 0, 1, 1, 1, 1.0, 1.0);
         makeJButton(panel2s, CASS, 0, 0, 1, 1, 1.0, 1.0);
         makeJButton(panel2s, cachesizes, 1, 0, 2, 1, 1.0, 1.0);
         makeJButton(panel2s, Box.createRigidArea(hpad40), 2, 0, 1, 1, 1.0, 1.0);
@@ -503,6 +555,7 @@ public class SkeletonTable extends JFrame
 	panel2.add(panel2s, BorderLayout.SOUTH);
 	ZMODE.setFont(boldFont);
 	STYLE.setFont(boldFont);
+	NEWFORMAT.setFont(boldFont);
 	VALUES.setFont(boldFont);
 	CASS.setFont(boldFont);
 	cachesizes.setFont(boldFont);
@@ -524,7 +577,7 @@ public class SkeletonTable extends JFrame
         dsc.addItemListener(this);
         dsc.setToolTipText("Select to display caching statistics after run");
         ufc.addItemListener(this);
-        ufc.setToolTipText("Select to use FILLVAL attribute entry for each variable");
+        ufc.setToolTipText("Select to use FORMAT attribute entry for each variable");
         zzc.addItemListener(this);
         zzc.setToolTipText("Select to convert -0.0 to 0.0");
 	abc.addItemListener(this);
@@ -684,6 +737,9 @@ public class SkeletonTable extends JFrame
                         if (strsty.equals("")) estyle = " ";
                         else estyle = "-style " + strsty + " ";
 
+                        if (strnfm.equals("")) enewformat = " ";
+                        else enewformat = "-advformat " + strnfm + " ";
+
 			if (skltspec.equals("") || skltspec.trim().equals("")) 
 			  SKLTfile = " ";
 			else {
@@ -708,12 +764,14 @@ public class SkeletonTable extends JFrame
                         else cdfDelimiter = "\"";
 
                         commandX = command  + strzz + struf + stros + strlp +
-				   strds + strpo + report + estyle + Zmode +
+				   strds + strpo + report + estyle +
+                                   enewformat + Zmode +
                                    Values + Caches + SKLTfile + cdfDelimiter +
                                    cdfspec + cdfDelimiter;
                         /**************
 			commandX = command  + strzz + struf + stros + strlp +
-				   strds + strpo + report + estyle + Zmode +
+				   strds + strpo + report + estyle + 
+                                   enewformat + Zmode +
                                    Values + Caches + SKLTfile + " " + cdfspec + " ";
                         *************/
                         String OS = System.getProperty("os.name").toLowerCase();
@@ -803,6 +861,16 @@ public class SkeletonTable extends JFrame
         }
     }
 
+/** Action for radio buttons for Style
+ */
+
+    class AdvFormatListener implements ActionListener {
+        public void actionPerformed(ActionEvent e) {
+           strnfm = e.getActionCommand();
+           ufc.setSelected(false);
+        }
+    }
+
 /** Action for radio buttons for Values
  */
 
@@ -879,9 +947,10 @@ public class SkeletonTable extends JFrame
 		  recX = 0;
 		}
         } else if (obj == ufc) { // "Use Format" checkbox
-                if (ufc.isSelected())
+                if (ufc.isSelected()) {
                   struf = "-format ";
-                else
+                  newformat.clearSelection();
+                } else
                   struf = "-noformat ";
         } else if (obj == osc) { // "Output to Screen" checkbox
                 if (osc.isSelected()) {
