@@ -1,4 +1,4 @@
-//$Id: VariableSpecPanel.java,v 1.1.1.1 2018/08/29 19:16:17 mhliu Exp $
+//$Id: VariableSpecPanel.java,v 1.1.1.1 2019/10/16 16:22:18 mhliu Exp $
 /******************************************************************************
 * Copyright 1996-2014 United States Government as represented by the
 * Administrator of the National Aeronautics and Space Administration.
@@ -208,7 +208,15 @@ public class VariableSpecPanel extends JLabeledPanel implements CDFConstants {
         else {
           if (dataType != CDF_EPOCH && dataType != CDF_EPOCH16 &&
               dataType != CDF_TIME_TT2000) {
-            padString = padValue.toString();
+            if (dataType == CDF_REAL4 || dataType == CDF_REAL8 ||
+                dataType == CDF_FLOAT || dataType == CDF_DOUBLE) {
+              String format;
+              try {
+                format = (String) var.getEntryData("FORMAT");
+              } catch (CDFException ce) { format = null; }
+              padString = CDFUtils.getStringFloatingData (padValue, format, ", ");
+            } else
+              padString = padValue.toString();
 	    if (dataType == CDF_CHAR || dataType == CDF_UCHAR)
 		pad.set("\""+padString+"\"");
 	    else
@@ -216,25 +224,25 @@ public class VariableSpecPanel extends JLabeledPanel implements CDFConstants {
             if (((String)pad.get()).length() >= 15) 
               pad.textField.setFont(new Font(padCurrFont.getName(),
                                              padCurrFont.getStyle(),
-                                             padCurrFont.getSize()-3));
+                                             padCurrFont.getSize()-2));
             else
               pad.textField.setFont(padCurrFont);
           } else {
 	    if (dataType == CDF_EPOCH) {
-              padString = Epoch.encode(((Double)padValue).doubleValue());
+              padString = Epoch.encode4(((Double)padValue).doubleValue());
 	      pad.set(padString);
               pad.textField.setFont(new Font(padCurrFont.getName(), padCurrFont.getStyle(), 
-					     padCurrFont.getSize()-3));
+					     padCurrFont.getSize()-1));
 	    } else if (dataType == CDF_EPOCH16) {
-              padString = Epoch16.encode(((double[])padValue));
+              padString = Epoch16.encode4(((double[])padValue));
               pad.set(padString);
               pad.textField.setFont(new Font(padCurrFont.getName(), padCurrFont.getStyle(),
-                                             padCurrFont.getSize()-5));
+                                             padCurrFont.getSize()-2));
 	    } else {
               padString = CDFTT2000.toUTCstring(((Long)padValue).longValue());
               pad.set(padString);
               pad.textField.setFont(new Font(padCurrFont.getName(), padCurrFont.getStyle(),
-                                             padCurrFont.getSize()-3));
+                                             padCurrFont.getSize()-1));
             }
 	  }
         }
