@@ -145,12 +145,12 @@ public class ReadCDF implements CDFConstants{
                           Object data = entry.getData();
                           if (eDataType == CDF_EPOCH) {
                               CDFUtils.printData (
-                                Epoch.encode(((Double) data).doubleValue()));
+                                Epoch.toEncode(((Double) data).doubleValue()));
                           } else if (eDataType == CDF_EPOCH16) {
-                              CDFUtils.printData (Epoch16.encode((double[])data));
+                              CDFUtils.printData (Epoch16.toEncode((double[])data));
                           } else if (eDataType == CDF_TIME_TT2000) {
                               CDFUtils.printData (
-                                CDFTT2000.encode(((Long)data).longValue()));
+                                CDFTT2000.toEncode(((Long)data).longValue()));
                           } else {
                             if (CDFUtils.isStringDataType(eDataType))
                               System.out.print("\"");
@@ -194,31 +194,53 @@ public class ReadCDF implements CDFConstants{
                        Variable v = cdf.getVariable(entry.getID());
                        System.out.print ("\t"+v.getName()+" ("+
                                         CDFUtils.getStringDataType(eDataType)+
-                                        "/"+entry.getNumElements()+
-                                        "): ");
-
+                                        "/"+entry.getNumElements()+"): ");
                        Object data = entry.getData();
                        if (eDataType == CDF_EPOCH) {
                            CDFUtils.printData (
-                               Epoch.encode(((Double) data).doubleValue()));
+                               Epoch.toEncode(((Double) data).doubleValue()));
                        } else if (eDataType == CDF_EPOCH16) {
-                           CDFUtils.printData (Epoch16.encode((double[])data));
+                           CDFUtils.printData (Epoch16.toEncode((double[])data));
                        } else if (eDataType == CDF_TIME_TT2000) {
                            CDFUtils.printData (
-                               CDFTT2000.encode(((Long) data).longValue()));
+                               CDFTT2000.toEncode(((Long) data).longValue()));
                        } else {
-                          if (CDFUtils.isStringDataType(eDataType))
-                            System.out.print("\"");
-                          CDFUtils.printData (data);
-                          if (CDFUtils.isStringDataType(eDataType))
-                            System.out.print("\"");
+                          if (entry.getScope() == VARIABLE_SCOPE) {
+                            if (CDFUtils.isStringDataType(eDataType)) {
+                              if (data instanceof String[]) {
+                                long ix = ((String[])data).length;
+                                System.out.println("\t("+ix+" string"+(ix>1?"s":"")+") ");
+                                int iy;
+                                for (iy=0; iy<ix; ++iy) {
+                                  if (iy != (ix-1))
+                                    System.out.println("\t\t\t\t\""+((String[])data)[iy]+"\""); 
+                                  else
+                                    System.out.print("\t\t\t\t\""+((String[])data)[iy]+"\"");
+                                }
+                              } else {
+                                System.out.print("\"");
+                                CDFUtils.printData (data);
+                                System.out.print("\"");
+                              }
+                            } else {
+                              String format;
+                              try {
+                                Attribute attr = cdf.getAttribute("FORMAT");
+                                Entry formatEntry = attr.getEntry (entry.getID());
+                                format = (String) formatEntry.getData();
+                              } catch (CDFException ee) {
+                                format = null;
+                              }
+                              CDFUtils.printDataWithFormat (data, format);
+                            }
+                          } else
+                            CDFUtils.printData (data);
                        }
                        System.out.println (" ");
                     }
                 }
                 System.out.println (" ");
               }
-
               /**************************************/
               /* Print out the Variable information */ 
               /**************************************/
@@ -269,14 +291,33 @@ public class ReadCDF implements CDFConstants{
 
                 // Print the user-define pad value if one exists. 
 		// if (v.checkPadValueExistence()) {
+/*
                   padValue = v.getPadValue(); 
                   if (dt == CDF_EPOCH)
-                    padValue = Epoch.encode(((Double) padValue).doubleValue());
+                    padValue = Epoch.toEncode(((Double) padValue).doubleValue());
                   else if (dt == CDF_EPOCH16)
-                    padValue = Epoch16.encode((double[]) padValue);
+                    padValue = Epoch16.toEncode((double[]) padValue);
                   else if (dt == CDF_TIME_TT2000)
-                    padValue = CDFTT2000.encode(((Long) padValue).longValue());
-                  System.out.print (" PadValue="+((CDFUtils.isStringDataType(dt)||CDFUtils.isEpochDataType(dt))?"\"":"")+padValue+((CDFUtils.isStringDataType(dt)||CDFUtils.isEpochDataType(dt))?"\"":""));
+                    padValue = CDFTT2000.toEncode(((Long) padValue).longValue());
+                  else if (dt != CDF_REAL4 && dt != CDF_FLOAT &&
+                           dt != CDF_REAL8 && dt != CDF_DOUBLE)
+                    System.out.print (" PadValue="+((CDFUtils.isStringDataType(dt)||
+                                                     CDFUtils.isEpochDataType(dt))?
+                                                    "\"":"")+padValue+
+                                                    ((CDFUtils.isStringDataType(dt)||
+                                                     CDFUtils.isEpochDataType(dt))?"\"":""));
+                  else {
+                      String format;
+                      try {
+                        Attribute attr = cdf.getAttribute("FORMAT");
+                        format = (String) attr.getEntry (v.getID()).getData();
+                      } catch (CDFException ee) {
+                        format = null;
+                      }
+                      System.out.print (" PadValue=");
+                      CDFUtils.printDataWithFormat (padValue,format);
+                  }
+*/
                 // }
 
                 blockingFactor = v.getBlockingFactor();
@@ -313,6 +354,14 @@ public class ReadCDF implements CDFConstants{
                 numRecs = v.getNumWrittenRecords();
                 varName = v.getName();
                 System.out.println (varName);
+                String format;
+                try {
+                  Attribute attr = cdf.getAttribute("FORMAT");
+                  format = (String) attr.getEntry (v.getID()).getData();
+                } catch (CDFException ee) {
+                  format = null;
+                }
+
                 for (i=0; i < varName.length(); i++)
                      System.out.print ("-");
                 System.out.println (" ");
@@ -329,17 +378,20 @@ public class ReadCDF implements CDFConstants{
                   if (pv != null) {
 		    if (myDT == CDF_EPOCH)
 		      System.out.println ("Pad value:        "+
-                         Epoch.encode(((Double)pv).doubleValue()));
+                         Epoch.toEncode(((Double)pv).doubleValue()));
 		    else if (myDT == CDF_EPOCH16)
 		      System.out.println ("Pad value:        "+
-                         Epoch16.encode((double[])pv));
+                         Epoch16.toEncode((double[])pv));
                     else if (myDT == CDF_TIME_TT2000)
                       System.out.println ("Pad value:        "+
                          CDFTT2000.toUTCstring(((Long)pv).longValue()));
                     else if (CDFUtils.isStringDataType(myDT))
                       System.out.println ("Pad value:        \""+ pv+"\"");
-                    else 
-		      System.out.println ("Pad value:        "+ pv);
+                    else {
+                      System.out.print ("Pad value:        ");
+                      CDFUtils.printDataWithFormat (pv, format);
+                      System.out.println("");
+                    }
 		  }
 		}
                 System.out.println ("Records:          "+
@@ -371,7 +423,7 @@ public class ReadCDF implements CDFConstants{
                      status = cdf.getStatus();
                      if (status == CDF_OK || status != VIRTUAL_RECORD_DATA) {
                        System.out.println ("Record # "+i+":");
-                       data.dumpData();
+                       data.dumpDataWithFormat(format);
                      }
                 }
                 System.out.println("");
