@@ -1,4 +1,4 @@
-// $Id: Attribute.java,v 1.1.1.1 2017/01/04 20:58:09 liu Exp $
+// $Id: Attribute.java,v 1.2 2019/12/09 21:17:40 mhliu Exp $
 /*
  * Copyright 1996-2014 United States Government as represented by the
  * Administrator of the National Aeronautics and Space Administration.
@@ -181,11 +181,15 @@ synchronized(myCDF) {
 	long entryID = -1;
 	long numRead = 0;
 	Entry curEntry;
-
 	if (theAttr.numEntries != 0) {
+            if ((theAttr.getScope() == VARIABLE_SCOPE) && 
+                (theAttr.numEntries > (theAttr.maxEntryNumber+1))) {
+               /* A ivariable entry(ies) without a variable(s)... */
+               theAttr.numEntries = theAttr.maxEntryNumber + 1;
+            }
 	    while (true) {
+                entryID++;
 		try {
-		    entryID++;
 		    curEntry = Entry.retrieve(theAttr, entryID);
 		    //theAttr.entries.addElement(curEntry);
 		    numRead++;
@@ -198,7 +202,6 @@ synchronized(myCDF) {
 		}
 	    }
 	}
-
 	return theAttr;
     }
 }
@@ -235,13 +238,14 @@ synchronized(myCDF) {
 	if ((scope != GLOBAL_SCOPE) && (scope != VARIABLE_SCOPE)) {
 	    throw new CDFException(BAD_SCOPE);
 	}
+        if (name == null || name.trim().length() == 0)
+            throw new CDFException(BAD_ATTR_NAME);
+
 	long ij = myCDF.getAttributeID(name);   
 
 	if (ij != -1) {              // Attribute already exists
 	    throw new CDFException(ATTR_EXISTS);
 	}
-	if (name == null || name.length() == 0) 
-	    throw new CDFException(BAD_ATTR_NAME);
 
 	Vector cmds = new Vector();
 	Vector item0 = new Vector();
