@@ -1,4 +1,4 @@
-//$Id: CDFData.java,v 1.3 2019/05/01 15:17:47 mhliu Exp $
+//$Id: CDFData.java,v 1.2 2020/02/18 17:28:59 mhliu Exp $
 /*
  * Copyright 1996-2014 United States Government as represented by the
  * Administrator of the National Aeronautics and Space Administration.
@@ -389,8 +389,6 @@ synchronized(v) {
         // Create the 1D _data object
         theData.buildDataObject();
 	// Select the variable and the correct record etc.
-//        v.select(recStart, recCount, recInterval, dimIndices, 
-//		 dimCounts, dimIntervals);
 
         cmds.addElement(new Long(SELECT_));
           cmds.addElement(new Long(CDF_));
@@ -634,7 +632,6 @@ synchronized(v) {
      * Translate a 1D array into a proper dimension.
      */
     private void arrayify() throws CDFException {
-
 	if (nDims <= 1 || numValues == 1) {
 	    if ((dataType == CDF_CHAR) || (dataType == CDF_UCHAR)) {
 		if (nDims == 0)
@@ -694,7 +691,8 @@ synchronized(v) {
 		// Get the correct 2D subarray to fill
 		if (n != 0) {
 		    for (int i = 0; i < (int)nDims-1; i++) {
-			boundaryCrossed = ((n % boundary[i]) == 0);
+//			boundaryCrossed = ((n % boundary[i]) == 0);
+			boundaryCrossed = (((n/numElements) % boundary[i]) == 0);
 			if (boundaryCrossed) {
 			    // Get the next sub array
 			    cIndex[i] += 1;
@@ -871,7 +869,6 @@ synchronized(v) {
 	    // be used since _dataArray = _data
 
 	    while (n < numValues) {
-//	    while (n < boundary[0]) {
 		// Get the correct 2D subarray to fill
 		if (n!=0) {
 		    for (int i = 0; i < (int)nDims-1; i++) {
@@ -1012,13 +1009,11 @@ synchronized(v) {
 	    nDims = ((recCount > 1) ? 1 : 0);
 	    int len = dimCounts.length;
 	    if (len == 1) {
-//		if (dimCounts[0] > 1) 
               if (dimCounts[0] > 1 || (numDims > 0 && varDimSizes[0] == 1))
 		    nDims ++;
 	    } else {
 		boolean multi=false;
 		for (int i=0; i<len; i++)
-//		    if (dimCounts[i] > 1)
                   if (dimCounts[i] > 1 || varDimSizes[i] == 1)
 			nDims ++;
 	    }
@@ -1143,16 +1138,6 @@ synchronized(v) {
                   for (i=0; i<itotal; i++)
                     ((byte [])_data)[j*numElms+i] = myBytes[i];
                 }
-//	        for (int i=0, j=0; i<numValues; i++, j++) {
-//		  if (j == numElements) j = 0;
-//                  if (j == ilen) j = 0;
-//		  ((byte [])_data)[i] = myBytes[j];
-//	        }
-//              } else { /* nul-string... fill with spaces */
-//	        for (int i=0; i<numValues; i++) {
-//		  ((byte [])_data)[i] = ((byte[]) (new String(" ").getBytes()))[0];
-//		  ((byte [])_data)[i] = 0;
-//	        }
               } 
 	    }
 	    break;
@@ -1333,7 +1318,8 @@ synchronized(v) {
     /**
      * Dumps variable data, one row at a time per record.  This is a generic
      * utility for dumping data to a screen.  Data can be scalar or 
-     * 1-dimensional or multi-dimensional array of any data type.<P>
+     * 1-dimensional or multi-dimensional array of any data type. This
+     * method dumps the data without using format.<P>
      *
      * The following example retrieves the first record, comprised of
      * 3x5 (3 rows and 5 columns) array, into a generic object and dumps 
@@ -1378,7 +1364,7 @@ synchronized(v) {
                     System.out.println ("\""+_dataArray.toString()+"\"");
                 }
                 else
-                    System.out.println(_dataArray.toString());
+                    System.out.println (_dataArray.toString());
             }
             else {
                 System.out.print("[");
@@ -1488,7 +1474,7 @@ synchronized(v) {
                 default:
                     break;
                 } /* switch (dataType) */
-                System.out.println("]");
+                System.out.println ("]");
             }
 
         /////////////////////////////////////////////////////////////
@@ -1668,7 +1654,386 @@ synchronized(v) {
                     default:
                         break;
                     } /* switch (dataType) */
-                    System.out.println("]");
+                    System.out.println ("]");
+                    n += dimSizes[nDims - 1];
+                }
+            }
+        }
+    }
+
+    /**
+     * Dumps variable data, one row at a time per record, with format.  This
+     * is a generic * utility for dumping data to a screen.  Data can be scalar
+     * or 1-dimensional or multi-dimensional array of any data type. The format
+     * is only applicable to variables of numerical data type. the format comes
+     * from variable's FORMAT attribute entry. Note: The FORMAT might be
+     * in original C or Fortran format form. This format is mainly used for
+     * floating point data. 
+     *
+     * The following example retrieves the first record, comprised of
+     * 3x5 (3 rows and 5 columns) array, into a generic object and dumps 
+     * its contents to screen one row at a time.  In this case three rows
+     *  will be displayed on a screen, each row containing 5 elements. 
+     * <PRE>
+     *     CDFData data;
+     *     String format = (String) var.getEntryData("FORMAT");
+     *     long[] dimIndices   = {0,0};
+     *     long[] dimIntervals = {3,5};
+     *     long[] dimSizes     = {1,1}; 
+     *     data = var.getHyperDataObject(0L,         // record start
+     *                                   1,          // record counts 
+     *                                   1,          // record interval
+     *                                   dimIndices,
+     *                                   dimSizes,
+     *                                   dimIntervals);
+     *     data.dumpDataWithFormat(format);
+     * </PRE>
+     *
+     * @param format A string format
+     *
+     */
+    public void dumpDataWithFormat(String format) {
+
+	if (format == null) {
+            dumpData();
+            return;
+        }
+        String jFormat = CDFUtils.CFtoJformat (format);
+        if (jFormat == null) {
+            dumpData();
+            return;
+        } 
+        
+        /////////////////////////////////////////////////////////////
+        //                                                         //
+        //                    Dump 1D Arrays                       //
+        //                                                         //
+        /////////////////////////////////////////////////////////////
+        long dataTYpe = _myVar.getDataType();
+        if (nDims <= 1 || numValues == 1) {
+            if (nDims == 0 || numValues == 1) {
+                if (dataTYpe == CDF_EPOCH) {
+                    Double lEpoch = (Double) _dataArray;
+                    System.out.println (Epoch.encode4(lEpoch.doubleValue()));
+                } else if (dataTYpe == CDF_EPOCH16) {
+                    double[] lEpoch16 = (double[]) _dataArray;
+                    System.out.println (Epoch16.encode4(lEpoch16));
+                } else if (dataTYpe == CDF_TIME_TT2000) {
+                    Long lEpoch = (Long) _dataArray;
+                    System.out.println (CDFTT2000.encode(lEpoch.longValue()));
+                } else if (dataTYpe == CDF_CHAR || dataTYpe == CDF_UCHAR) {
+                    System.out.println ("\""+_dataArray.toString()+"\"");
+                }
+                else {
+                    if ((dataTYpe != CDF_REAL4 && dataTYpe != CDF_REAL8 &&
+                         dataTYpe != CDF_FLOAT && dataTYpe != CDF_DOUBLE) ||
+                        CDFUtils.isFloatingPadValue (dataTYpe, _dataArray) == 1)
+                       System.out.println (_dataArray.toString());
+                    else
+                       System.out.format(jFormat+"%n", _dataArray);
+                }
+            }
+            else {
+                System.out.print("[");
+                int dataTypeX = (int)_myVar.getDataType();
+                switch (dataTypeX) {
+                case (int)CDF_CHAR:
+                case (int)CDF_UCHAR:
+                    for (int j=0; j<dimSizes[nDims - 1]; j++) {
+                        if (j>0) System.out.print(",");
+                        System.out.print("\""+((String [])_dataArray)[j]+"\"");
+                    }
+                    break;
+                case (int)CDF_BYTE:
+                case (int)CDF_INT1:
+                    for (int j=0; j<dimSizes[nDims - 1]; j++) {
+                        if (j>0) System.out.print(",");
+                        System.out.print(((byte [])_dataArray)[j]);
+                    }
+                    break;
+                case (int)CDF_INT2:
+                    for (int j=0; j<dimSizes[nDims - 1]; j++) {
+                        if (j>0) System.out.print(",");
+                        System.out.print(((short [])_dataArray)[j]);
+                    }
+                    break;
+                case (int)CDF_UINT1:
+                    for (int j=0; j<dimSizes[nDims - 1]; j++) {
+                        if (j>0) System.out.print(",");
+                        if (((short [])_dataArray)[j] >=0) {
+                          System.out.print(((short [])_dataArray)[j]);
+			} else {
+			  short tmp = (short)(((short [])_dataArray)[j]+256); 
+                          System.out.print(tmp);
+			}
+                    }
+                    break;
+                case (int)CDF_INT4:
+                    for (int j=0; j<dimSizes[nDims - 1]; j++) {
+                        if (j>0) System.out.print(",");
+                        System.out.print(((int [])_dataArray)[j]);
+                    }
+                    break;
+                case (int)CDF_UINT2:
+                    for (int j=0; j<dimSizes[nDims - 1]; j++) {
+                        if (j>0) System.out.print(",");
+                        if (((int [])_dataArray)[j] >=0) {
+                          System.out.print(((int [])_dataArray)[j]);
+                        } else {
+			  int tmp = (int)(((int [])_dataArray)[j]+65536);
+                          System.out.print(tmp);
+			}
+                    }
+                    break;
+
+                case (int)CDF_UINT4:
+                    for (int j=0; j<dimSizes[nDims - 1]; j++) {
+                        if (j>0) System.out.print(",");
+                        if (((long [])_dataArray)[j] >=0) {
+                          System.out.print(((long [])_dataArray)[j]);
+                        } else {
+			  long tmp = (long)(((long [])_dataArray)[j]+
+					    4294967296L);
+                          System.out.print(tmp);
+			}
+                    }
+                    break;
+                case (int)CDF_INT8:
+                case (int)CDF_TIME_TT2000:
+                    for (int j=0; j<dimSizes[nDims - 1]; j++) {
+                        if (j>0) System.out.print(",");
+                        if (dataTypeX == (int)CDF_INT8) {
+                          System.out.print(((long [])_dataArray)[j]);
+                        } else
+                          System.out.print(CDFTT2000.encode(((long [])_dataArray)[j]));
+                    }
+                    break;
+                case (int)CDF_REAL4:
+                case (int)CDF_FLOAT:
+                    for (int j=0; j<dimSizes[nDims - 1]; j++) {
+                        if (j>0) System.out.print(",");
+                        if (CDFUtils.isFloatingPadValue (dataType, ((float [])_dataArray)[j]) != 1)
+                           System.out.print(((float [])_dataArray)[j]);
+                        else
+                           System.out.format(jFormat, ((float [])_dataArray)[j]);
+                    }
+                    break;
+                case (int)CDF_REAL8:
+                case (int)CDF_DOUBLE:
+                    for (int j=0; j<dimSizes[nDims - 1]; j++) {
+                        if (j>0) System.out.print(",");
+                        if (CDFUtils.isFloatingPadValue (dataType, ((double [])_dataArray)[j]) != 1)
+                           System.out.print(((double [])_dataArray)[j]);
+                        else
+                           System.out.format(jFormat, ((double [])_dataArray)[j]);
+                    }
+                    break;
+                case (int)CDF_EPOCH:
+                    for (int j=0; j<dimSizes[nDims - 1]; j++) {
+                        if (j>0) System.out.print(",");
+			System.out.print(
+                                   Epoch.encode4(((double [])_dataArray)[j]));
+                    }
+                    break;
+                case (int)CDF_EPOCH16:
+		    double[] tmp = new double[2];
+                    for (int j=0; j<dimSizes[nDims - 1]; j++) {
+                        if (j>0) System.out.print(",");
+                        tmp[0] = ((double [])_dataArray)[2*j];
+                        tmp[1] = ((double [])_dataArray)[2*j+1];
+                        System.out.print(Epoch16.encode4(tmp));
+                    }
+                    break;
+                default:
+                    break;
+                } /* switch (dataType) */
+                System.out.println ("]");
+            }
+
+        /////////////////////////////////////////////////////////////
+        //                                                         //
+        //              Dump Multidimensional Arrays               //
+        //                                                         //
+        /////////////////////////////////////////////////////////////
+
+        } else {
+            /*
+             * Setup the subArrays array
+             * cIndex is the holds the index for the current subarray
+             * boundary is the # of values in the subarray
+             */
+            Object aRow = null;
+            Object [] subArrays = new Object[(int)nDims-1];
+            int [] cIndex   = new int[(int)nDims-1];
+            long [] boundary = new long[(int)nDims-1];
+
+            subArrays[0] = _dataArray;
+            cIndex[0] = 0;
+	    boundary[0] = product(dimSizes,0,(int)nDims);
+
+            for (int i=1; i<(int)nDims-1;i++) {
+                subArrays[i] = Array.get(subArrays[i-1], 0);
+                boundary[i] = product(dimSizes,i,(int)nDims);
+                cIndex[i] = 0;
+            }
+
+            int n = 0; // The current element in the _data
+            Object cObject = _dataArray;  // A temp object to hold a subarray
+            boolean boundaryCrossed;
+            while (n < boundary[0]) {
+                // Get the correct 2D subarray to print
+                if (n != 0) {
+                    for (int i = 0; i < (int)nDims-1; i++) {
+                        boundaryCrossed = ((n % boundary[i]) == 0);
+                        if (boundaryCrossed) {
+                            // Get the next sub array
+                            cIndex[i]+=1;
+                            cObject = Array.get(cObject, cIndex[i]);
+                            subArrays[i] = cObject;
+
+                            // Get the first element of each
+                            // subsequent subarray
+                            for (int j=i+1;j<(int)nDims-1;j++) {
+                                cIndex[j] = 0;
+                                subArrays[j] =
+                                    Array.get(subArrays[j-1],cIndex[j]);
+                            }
+                            break;
+
+                        } else {
+                            cObject = subArrays[i];
+                        }
+                    }
+                }
+
+                // Fill the correct elements of _data
+                for (int i=0;i<dimSizes[(int)nDims-2];i++) {
+                    System.out.print("[");
+                    int dataTypeX = (int)_myVar.getDataType();
+                    switch (dataTypeX) {
+                    case (int)CDF_CHAR:
+                    case (int)CDF_UCHAR:
+                        aRow =
+                            (String [])Array.get(subArrays[(int)nDims - 2], i);
+                        for (int j=0; j<dimSizes[nDims - 1]; j++) {
+                            if (j>0) System.out.print(",");
+                            System.out.print("\""+((String [])aRow)[j]+"\"");
+                        }
+                        break;
+                    case (int)CDF_BYTE:
+                    case (int)CDF_INT1:
+                        aRow = (byte [])Array.get(subArrays[(int)nDims - 2], i);
+                        for (int j=0; j<dimSizes[nDims - 1]; j++) {
+                            if (j>0) System.out.print(",");
+                            System.out.print(((short [])aRow)[j]);
+                        }
+                        break;
+                    case (int)CDF_INT2:
+                        aRow = (short [])Array.get(subArrays[(int)nDims - 2], i);
+                        for (int j=0; j<dimSizes[nDims - 1]; j++) {
+                            if (j>0) System.out.print(",");
+                            System.out.print(((short [])aRow)[j]);
+                        }
+                        break;
+                    case (int)CDF_UINT1:
+                        aRow = (short [])Array.get(subArrays[(int)nDims - 2], i);
+                        for (int j=0; j<dimSizes[nDims - 1]; j++) {
+                            if (j>0) System.out.print(",");
+                            if (((short [])aRow)[j] >=0) {
+                                System.out.print(((short [])aRow)[j]);
+			    } else {
+				short tmp = (short) (((short [])aRow)[j] + 256);
+                                System.out.print(tmp);
+			    }
+                        }
+                        break;
+                    case (int)CDF_INT4:
+                        aRow = (int [])Array.get(subArrays[(int)nDims - 2], i);
+                        for (int j=0; j<dimSizes[nDims - 1]; j++) {
+                            if (j>0) System.out.print(",");
+                            System.out.print(((int [])aRow)[j]);
+                        }
+                        break;
+                    case (int)CDF_UINT2:
+                        aRow = (int [])Array.get(subArrays[(int)nDims - 2], i);
+                        for (int j=0; j<dimSizes[nDims - 1]; j++) {
+                            if (j>0) System.out.print(",");
+                            if (((int [])aRow)[j] >=0) {
+                                System.out.print(((long [])aRow)[j]);
+                            } else {
+                                int tmp = (int) (((int [])aRow)[j] + 65536);
+                                System.out.print(tmp);
+                            }
+                        }
+                        break;
+                    case (int)CDF_UINT4:
+                        aRow = (long [])Array.get(subArrays[(int)nDims - 2], i);
+                        for (int j=0; j<dimSizes[nDims - 1]; j++) {
+                            if (j>0) System.out.print(",");
+                            if (((long [])aRow)[j] >=0) {
+                                System.out.print(((long [])aRow)[j]);
+                            } else {
+                                long tmp = (long) (((long [])aRow)[j]+
+						   4294967296L);
+                                System.out.print(((long [])aRow)[j]);
+                            }
+                        }
+                        break;
+                    case (int)CDF_INT8:
+                    case (int)CDF_TIME_TT2000:
+                        aRow = (long [])Array.get(subArrays[(int)nDims - 2], i);
+                        for (int j=0; j<dimSizes[nDims - 1]; j++) {
+                            if (j>0) System.out.print(",");
+                            if (dataTypeX == (int)CDF_INT8) {
+                              System.out.print(((long [])aRow)[j]);
+                            } else
+                              System.out.print(CDFTT2000.encode(((long [])aRow)[j]));
+                        }
+                        break;
+                    case (int)CDF_REAL4:
+                    case (int)CDF_FLOAT:
+                        aRow = (float [])Array.get(subArrays[(int)nDims - 2], i);
+                        for (int j=0; j<dimSizes[nDims - 1]; j++) {
+                            if (j>0) System.out.print(",");
+                            if (CDFUtils.isFloatingPadValue (dataType, ((float [])aRow)[j]) != 1)
+                               System.out.print(((float [])aRow)[j]);
+                            else
+                               System.out.format(format, ((float [])aRow)[j]);
+                        }
+                        break;
+                    case (int)CDF_REAL8:
+                    case (int)CDF_DOUBLE:
+                        aRow = (double [])Array.get(subArrays[(int)nDims - 2], i);
+                        for (int j=0; j<dimSizes[nDims - 1]; j++) {
+                            if (j>0) System.out.print(",");
+                            if (CDFUtils.isFloatingPadValue (dataType, ((double [])aRow)[j]) != 1)
+                               System.out.print(((double [])aRow)[j]);
+                            else
+                               System.out.format(format, ((double [])aRow)[j]);
+                        }
+                        break;
+                    case (int)CDF_EPOCH:
+                        aRow = (double [])Array.get(subArrays[(int)nDims - 2], i);
+                        for (int j=0; j<dimSizes[nDims - 1]; j++) {
+                            if (j>0) System.out.print(",");
+			    System.out.print(
+                                       Epoch.encode4(((double [])aRow)[j]));
+                        }
+                        break;
+                    case (int)CDF_EPOCH16:
+			double tmp[] = new double[2];
+                        aRow = (double [])Array.get(subArrays[(int)nDims - 2], i);
+                        for (int j=0; j<dimSizes[nDims - 1]; j++) {
+                            if (j>0) System.out.print(",");
+                            tmp[0] = ((double [])aRow)[2*j];
+                            tmp[1] = ((double [])aRow)[2*j+1];
+                            System.out.print(Epoch16.encode4(tmp));
+                        }
+                        break;
+                    default:
+                        break;
+                    } /* switch (dataType) */
+                    System.out.println ("]");
                     n += dimSizes[nDims - 1];
                 }
             }
@@ -1691,7 +2056,7 @@ synchronized(v) {
 	    specs = new StringBuffer();
 	int nSpaces;
 
-	System.err.println("Data dump for "+_myVar+": ");
+	System.err.println ("Data dump for "+_myVar+": ");
 
 	// Get the Data type in a human form
 	sb.append(CDFUtils.getStringDataType(_myVar.getDataType()));
@@ -1734,7 +2099,7 @@ synchronized(v) {
 	}
 	specs.append("]/");
 	specs.append(_dataArray.getClass().getName());
-	System.err.println(specs.toString());
+	System.err.println (specs.toString());
 
 	/////////////////////////////////////////////////////////////
 	//                                                         //
