@@ -1,4 +1,4 @@
-// $Id: CDFTools.java,v 1.1.1.1 2018/08/29 19:16:17 mhliu Exp $
+// $Id: CDFTools.java,v 1.2 2020/01/31 14:47:47 mhliu Exp $
 /*
  * Copyright 1996-2014 United States Government as represented by the
  * Administrator of the National Aeronautics and Space Administration.
@@ -19,7 +19,7 @@ import gsfc.nssdc.cdf.util.*;
  * Created: Tue Nov 24 16:14:50 1998
  *
  * @author Phil Williams
- * @version $Id: CDFTools.java,v 1.1.1.1 2018/08/29 19:16:17 mhliu Exp $
+ * @version $Id: CDFTools.java,v 1.2 2020/01/31 14:47:47 mhliu Exp $
  */
 
 public class CDFTools implements CDFConstants {
@@ -277,15 +277,15 @@ public class CDFTools implements CDFConstants {
                                   neg2posfp0, statistics, screen, page, values,
                                   valueList, zMode, reportType, null);
         else {
-          StringBuffer sb = new StringBuffer();
-          if (cacheSizeD > 0) sb = sb.append(""+cacheSizeD+"d");
+          StringBuffer cs = new StringBuffer();
+          if (cacheSizeD > 0) cs = cs.append(""+cacheSizeD+"d");
           if (cacheSizeS > 0) {
-            if (cacheSizeD > 0) sb = sb.append(","+cacheSizeS+"s");
-            else sb = sb.append(""+cacheSizeS+"s");
+            if (cacheSizeD > 0) cs = cs.append(","+cacheSizeS+"s");
+            else cs = cs.append(""+cacheSizeS+"s");
           }
           CDFTools.skeletonTable(skeletonName, cdfName, log, format, 
                                  neg2posfp0, statistics, screen, page, values,
-                                 valueList, zMode, reportType, sb.toString());
+                                 valueList, zMode, reportType, cs.toString());
         } 
     }
 
@@ -409,20 +409,20 @@ public class CDFTools implements CDFConstants {
                                   neg2posfp0, statistics, screen, page, values,
                                   valueList, zMode, reportType, null);
         else {
-          StringBuffer sb = new StringBuffer();
-          if (cacheSizeD > 0) sb = sb.append(""+cacheSizeD+"d");
+          StringBuffer cs = new StringBuffer();
+          if (cacheSizeD > 0) cs = cs.append(""+cacheSizeD+"d");
           if (cacheSizeS > 0) {
-            if (cacheSizeD > 0) sb = sb.append(","+cacheSizeS+"s");
-            else sb = sb.append(""+cacheSizeS+"s");
+            if (cacheSizeD > 0) cs = cs.append(","+cacheSizeS+"s");
+            else cs = cs.append(""+cacheSizeS+"s");
           }
           if (cacheSizeC > 0) {
             if (cacheSizeD > 0 || cacheSizeS > 0)
-              sb = sb.append(","+cacheSizeC+"c");
-            else sb = sb.append(""+cacheSizeC+"c");
+              cs = cs.append(","+cacheSizeC+"c");
+            else cs = cs.append(""+cacheSizeC+"c");
           }
           CDFTools.skeletonTable(skeletonName, cdfName, log, format, 
                                  neg2posfp0, statistics, screen, page, values,
-                                 valueList, zMode, reportType, sb.toString());
+                                 valueList, zMode, reportType, cs.toString());
         } 
     }
 
@@ -550,6 +550,150 @@ public class CDFTools implements CDFConstants {
 	throws java.io.IOException, InterruptedException
     {
 
+        CDFTools.skeletonTable(skeletonName, cdfName, log, format,
+                               neg2posfp0, statistics, screen, page, values,
+                               valueList, zMode, reportType, cacheSize, null);
+    }
+
+    /**
+     * skeletonTable produces a skeleton table from a CDF.  A
+     * skeleton table is a text file which can be read by the
+     * SkeletonCDF program to build a skeleton CDF.
+     *
+     * @param skeletonName is the pathname of the skeleton table
+     *            to be created.  (Do not enter an extension because ".skt"
+     *            is appended automatically).  If <B>null</B> is specified, the
+     *            skeleton table is named &lt;cdfName&gt;.skt in the current
+     *            directory<BR><BR>
+     *
+     * @param cdfName The pathname of the CDF from which the skeleton table
+     *                will be created.  Do not enter an extension.<BR><BR>
+     *               
+     * @param log   Specifies whether or not messages are displayed as the
+     *             program executes.<BR><BR>
+     *            
+     * @param format Specifies whether or not the FORMAT attribute is used
+     *            when writing variable values (if the FORMAT attribute
+     *            exists and an entry exists for the variable). Metadata
+     *            always uses noformat form.<BR><BR>
+     *
+     * @param neg2posfp0
+     *            Specifies whether or not -0.0 is converted to 0.0 by the CDF
+     *            library when read from a CDF.  -0.0 is an illegal floating
+     *            point value on VAXes and DEC Alphas running OpenVMS.<BR><BR>
+     *
+     * @param statistics Specifies whether or not caching statistics
+     *            are displayed at the end of each CDF.<BR><BR>
+     *                 
+     * @param screen Specifies whether or not the skeleton table is displayed
+     *            on the terminal screen (written to the "standard output").
+     *            If not, the skeleton table is written to a file.<BR><BR>
+     *                       
+     * @param page If the skeleton table is being displayed on the terminal
+     *            screen, specifies whether or not the output is displayed
+     *            one page (screen) at a time.<BR><BR>
+     *                       
+     * @param values Specifies which variable values are to
+     *           be put in the skeleton table.  It may be one of
+     *           the following...<BR><BR>
+     *           <DL>
+     *              <DT>CDFTools.NO_VALUES
+     *                 <DD>Ignore all NRV data values.
+     *              <DT>CDFTools.NRV_VALUES
+     *                 <DD>Put NRV data values in the skeleton table.
+     *              <DT>CDFTools.RV_VALUES
+     *                 <DD>Put RV variable values in the skeleton table.
+     *               <DT>CDFTools.ALL_VALUES
+     *                 <DD>Put all variable values in the skeleton table.
+     *               <DT>CDFTools.NAMED_VALUES
+     *                  <DD>Put named variables values in the skeleton table.
+     *                      This requires that valueList be non-null
+     *           </DL><BR><BR>
+     *
+     * @param valueList the named variables to list values.<BR><BR>
+     *
+     * @param zMode Specifies which zMode should be used.  May be one
+     *            of the following...<BR><BR>
+     *
+     *               <DL>
+     *               <DT>0
+     *                 <DD>Indicates that zMode is disabled.
+     *               <DT>1
+     *                  <DD>Indicates that zMode/1 should be used (the
+     *                       dimension variances of rVariables will be
+     *                       preserved).
+     *               <DT>2
+     *                  <DD>Indicates that zMode/2 should be used (the
+     *                       dimensions of rVariables having a variance
+     *                       of NOVARY (false) are hidden.
+     *               </DL><BR><BR>
+     *
+     * @param reportType Specifies the types of return status codes from the CDF
+     *            library which should be reported/displayed.  <tt>report</tt>
+     *            is a bit mask made up from the following
+     *            CDFTools.NO_REPORTS, CDFTools.REPORT_ERRORS, 
+     *            CDFTools.REPORT_WARNINGS and CDFTools.REPORT_INFORMATION<BR><BR>
+     *
+     * @param cacheSize The number of buffers to be used for the CDF's dotCDF
+     *            file, staging file, and compression scratch file. This field
+     *            used only in the CDF access process will not change anything
+     *            to the contents of the skeleton table. Large number(s) will
+     *            likely reduce physical I/Os if variable data are involved. 
+     *            If this field is null, the default cache sizes chosen by
+     *            the CDF library are used.  The cache sizes are specified
+     *            with a comma-separated list of &lt;number&gt;&lt;type&gt; pairs where
+     *            &lt;number&gt; is the number of cache buffers and &lt;type&gt; is the
+     *            type of file.  The file &lt;type&gt;'s are as follows: `d' for
+     *            the dotCDF file, `s' for the staging file, and `c' for the
+     *            compression scratch file.  For example, `200d,100s'
+     *            specifies 200 cache buffers for the dotCDF file and 100
+     *            cache buffers for the staging file.  The dotCDF file cache
+     *            size can also be specified without the `d' &lt;type&gt; for
+     *            compatibility with older CDF releases (eg. `200,100s').
+     *            Note that not all of the file types must be specified.
+     *            Those not specified will receive a default cache size.<BR><BR>
+     * @param advFormat This new argument supersedes the prior format argument.
+     *            It accepts one of "best", "no", "metaonly", "dataonly" or "all"
+     *            options. "best" option all use the best approach to encode
+     *            floating point data with a higher precision, even larger than
+     *            the FORMAT attribute for both metadata and data. "no" option
+     *            will not use and FORMAT attribute, "metaonly" will use
+     *            FORMAT attribute for metdata only. "dataonly" will use
+     *            FORMAT attribute for data only. "all" option will use
+     *            FORMAT attribute for both metadata and data. "best" option
+     *            is the default. If null is passed in, which is the old 
+     *            method calling this method, it is changed to "best" option 
+     *            that works as C based tool would do.
+     *
+     *
+     * @throws java.io.IOException An exception is thrown if the file is bad
+     *                             or non-existent
+     * @throws InterruptedException An exception is thrown if an interrupt is
+     *                              issued
+     *
+     * <B>Note:</B><BR>
+     *    When running an application that use this static method, make sure
+     *    this <b>cdf.base</b> system property is defined (to the cdf installation).
+     *    For example, <BR>
+     *    java -Dcdf.base=/home/cdf/cdf34_1-dist MyApp <BR>
+     */
+    public static void skeletonTable(String skeletonName,
+				     String cdfName,
+				     boolean log,
+				     boolean format,
+				     boolean neg2posfp0,
+				     boolean statistics,
+				     boolean screen,
+				     boolean page,
+				     int values,
+				     String [] valueList,
+				     int zMode,
+				     int reportType,
+				     String cacheSize,
+				     String advFormat)
+	throws java.io.IOException, InterruptedException
+    {
+
 	// StringBuffers are faster than using String and +
 	StringBuffer cmd = new StringBuffer();  
 	cmd.append(cmdBase).append("skeletontable ");
@@ -592,6 +736,20 @@ public class CDFTools implements CDFConstants {
 	    cmd.append("no");
 	cmd.append("format ");
 
+        if (advFormat != null) {
+            if (advFormat.toLowerCase().equals("best"))
+              cmd.append("-advformat \"best \"");
+            else if (advFormat.toLowerCase().equals("no"))
+              cmd.append("-advformat \"no \"");
+            else if (advFormat.toLowerCase().equals("metaonly"))
+              cmd.append("-advformat \"metaonly \"");
+            else if (advFormat.toLowerCase().equals("dataonly"))
+              cmd.append("-advformat \"dataonly \"");
+            else if (advFormat.toLowerCase().equals("all"))
+              cmd.append("-advformat \"all \"");
+        } else
+          cmd.append("-advformat \"best \"");
+
 	cmd.append("-");
 	if (!neg2posfp0)
 	    cmd.append("no");
