@@ -1,4 +1,4 @@
-// $Id: CDFUtils.java,v 1.1.1.1 2018/08/29 19:16:17 mhliu Exp $
+// $Id: CDFUtils.java,v 1.2 2020/03/23 19:17:19 mhliu Exp $
 /*
  * Copyright 1996-2014 United States Government as represented by the
  * Administrator of the National Aeronautics and Space Administration.
@@ -292,7 +292,7 @@ public class CDFUtils implements CDFConstants {
      */
     public static void printData (Object data, int which) {
 
-        CDFUtils.printData (data, which, false);
+        CDFUtils.printData (data, which, true);
     }
 
     /**
@@ -321,7 +321,7 @@ public class CDFUtils implements CDFConstants {
      */
     public static void printData (Object data, PrintWriter outWriter) {
 
-	CDFUtils.printData(data, outWriter, 0, false);
+	CDFUtils.printData(data, outWriter, 0, true);
     }
 
     /**
@@ -338,7 +338,7 @@ public class CDFUtils implements CDFConstants {
      */
     public static void printData (Object data, PrintWriter outWriter,
 				  int which) {
-        CDFUtils.printData(data, outWriter, which, false);
+        CDFUtils.printData(data, outWriter, which, true);
     }
 
     /**
@@ -437,6 +437,357 @@ public class CDFUtils implements CDFConstants {
     }
 
 
+    /**
+     *  Prints the value of the given data on the screen.  Data can be a 
+     *  java primitive data type, Java Object (non-array), or 
+     *  1-dimensional array of primitive Java data type. The format is mainly
+     *  applicable to floating point typed data.
+     *
+     *  @param data the data to be printed
+     *  @param format the format specifically for the floating point data
+     *
+     */
+    public static void printDataWithFormat (Object data, String format) {
+
+	CDFUtils.printDataWithFormat(data, format, 0, true);
+    }
+
+    /**
+     *  Prints the value of the given data on the screen.  Data can be a
+     *  java primitive data type, Java Object (non-array), or
+     *  1-dimensional array of primitive Java data type.
+     *  Note: The format is mainly used for floating point data.
+     *
+     *  @param data the data to be printed
+     *  @param format the format specifically for the floating point data
+     *  @param which the Epoch data type data indicator
+     *               1 if CDF_EPOCH, 2 if CDF_EPOCH16 or 3 if CDF_TIME_TT2000
+     *  @param iso8601 the ISO 8601 indicator for EPOCH data
+     *
+     */
+    public static void printDataWithFormat (Object data, String format,
+                                            int which, boolean iso8601) {
+
+        CDFUtils.printDataWithFormat(data, format, which, iso8601, "");
+    }
+
+    /**
+     *  Prints the value of the given data on the screen.  Data can be a
+     *  java primitive data type, Java Object (non-array), or
+     *  1-dimensional array of primitive Java data type.
+     *  Note: The format is mainly used for floating point data.
+     *
+     *  @param data the data to be printed
+     *  @param format the format specifically for the floating point data
+     *  @param which the Epoch data type data indicator
+     *               1 if CDF_EPOCH, 2 if CDF_EPOCH16 or 3 if CDF_TIME_TT2000
+     *  @param iso8601 the ISO 8601 indicator for EPOCH data
+     *  @param addZ Added the passed string to the end, (likely a "Z", to
+     *              all CDF epoch data types, not just CDF_TIME_TT2000)
+     *
+     */
+    public static void printDataWithFormat (Object data, String format,
+                                            int which, boolean iso8601,
+                                            String addZ) {
+
+        if (format == null) {
+          CDFUtils.printData(data, which, iso8601, addZ);
+          return;
+        }
+        String jFormat = CDFUtils.CFtoJformat(format);
+        if (jFormat == null || CDFUtils.isFloatingPadValue (data) == 1) {
+          CDFUtils.printData (data, which, iso8601, addZ);
+          return;
+        }
+        int  i, arrayLength, jj = 1;
+        String signature = CDFUtils.getSignature(data);
+	if (which == 2) jj = 2;
+        if (signature.charAt(0) == '[') {
+            arrayLength = Array.getLength(data);
+            for (i=0; i < arrayLength; i=i+jj) {
+                 if (signature.charAt(1) == 'B') {
+//                   System.out.format (jFormat+(i==(arrayLength-jj)?"":" "),
+//                                      Array.getByte(data,i));
+                     System.out.print (Array.getByte(data,i)+
+                                       (i==(arrayLength-jj)?"":" "));
+
+                 } else if (signature.charAt(1) == 'S') {
+//                   System.out.format (jFormat+(i==(arrayLength-jj)?"":" "),
+//                                      Array.getShort(data,i));
+                     System.out.print (Array.getShort(data,i)+
+                                       (i==(arrayLength-jj)?"":" "));
+
+
+                 } else if (signature.charAt(1) == 'I') {
+//                   System.out.format (jFormat+(i==(arrayLength-jj)?"":" "),
+//                                      Array.getInt(data,i));
+                     System.out.print (Array.getInt(data,i)+
+                                       (i==(arrayLength-jj)?"":" "));
+
+
+                 } else if (signature.charAt(1) == 'J') {
+                     if (which == 0) {
+//                       System.out.format (jFormat+(i==(arrayLength-jj)?"":" "),
+//                                          Array.getLong(data,i));
+                         System.out.print (Array.getLong(data,i)+
+                                           (i==(arrayLength-jj)?"":" "));
+
+                     } else
+                       System.out.print (CDFTT2000.encode(Array.getLong(data,i))+
+                                         addZ+(i==(arrayLength-jj)?"":" "));
+
+                 } else if (signature.charAt(1) == 'F') {
+                       float value = Array.getFloat(data,i);
+                       if (CDFUtils.isFloatingPadValue(value) == 0)
+                         System.out.format (jFormat+(i==(arrayLength-jj)?"":" "),
+                                            value);
+                       else
+                         System.out.print (value+(i==(arrayLength-jj)?"":" "));
+
+                 } else if (signature.charAt(1) == 'D') {
+		   if (which == 1) {
+		     System.out.print (((!iso8601)?
+                                        Epoch.encode(Array.getDouble(data,i)):
+                                        (Epoch.encode4(Array.getDouble(data,i))+
+                                         addZ))+(i==(arrayLength-jj)?"":" "));
+                   } else if (which == 2) {
+                     double[] mmm = new double[2];
+                     mmm[0] = Array.getDouble(data,i);
+                     mmm[1] = Array.getDouble(data,i+1);
+                     System.out.print (((!iso8601)?
+                                        Epoch16.encode(mmm):
+                                        (Epoch16.encode4(mmm)+
+                                         addZ))+(arrayLength==2?"":" "));
+		   } else {
+                        double value = Array.getDouble(data,i);
+                       if (CDFUtils.isFloatingPadValue(value) == 0)
+                         System.out.format (jFormat+(i==(arrayLength-jj)?"":" "),
+                                            value);
+                       else
+                         System.out.print (value+(i==(arrayLength-jj)?"":" "));
+                   }
+                 } else {
+                     if (i>0) System.out.print(" \"");
+                     System.out.print (Array.get((String[])data, i));
+                     if (i<(arrayLength-1)) System.out.print("\" ");
+                 }
+            }
+        }
+        else {
+	   if (which == 1) 
+             System.out.print ((!iso8601)?
+                               Epoch.encode(((Double)data).doubleValue()):
+                               Epoch.encode4(((Double)data).doubleValue())+addZ);
+           else if (which == 3)
+             System.out.print (CDFTT2000.encode(((Long)data).longValue())+addZ);
+           else {
+               if ((signature.indexOf("Float") != -1 ||
+                    signature.indexOf("Double") != -1)  &&
+                   CDFUtils.isFloatingPadValue(data) == 0)
+                 System.out.format (jFormat,data);
+               else
+                 System.out.print (data);
+                 
+           }
+	}
+    }
+
+
+    /**
+     *  Prints the value of the given data on the screen.  Data can be a
+     *  java primitive data type, Java Object (non-array), or
+     *  1-dimensional array of primitive Java data type.
+     *
+     *  @param data the data to be printed
+     *  @param format the format specifically for the floating point data
+     *  @param which the Epoch data type data indicator
+     *               1 if CDF_EPOCH, 2 if CDF_EPOCH16 or 3 if CDF_TIME_TT2000
+     *
+     */
+    public static void printDataWithFormat (Object data, String format,
+                                            int which) {
+
+        CDFUtils.printDataWithFormat (data, format, which, false);
+    }
+
+    /**
+     *  Prints the value of the given data to the place designated by
+     *  PrintWriter that can be a file, Sysem.out, System.err, and etc.  
+     *  Data can be a java primitive data type, Java Object (non-array), or 
+     *  1-dimensional array of primitive Java data type. <P>
+     *
+     *  The following example will send the contents of the given data
+     *  to "myoutput.dat". 
+     *  <PRE>
+     *     OutputStreamWriter outWriter = null;
+     *     PrintWriter out = null;
+     *     try {
+     *          outWriter = new OutputStreamWriter("myoutput.dat", "UTF-8");
+     *          out = new PrintWriter(outWriter, true);
+     *     } catch (Exception e) {
+     *         System.out.println ("Exception occurred: "+e);
+     *     }
+     *     CDFUtils.printData (data, out);
+     *  </PRE>
+     *
+     *  @param data the data to be printed <P>
+     *  @param format the format specifically for the floating point data
+     *  @param outWriter the print writer to which formatted representations 
+     *                   of the object/data is printed as a text-output stream
+     */
+    public static void printDataWithFormat (Object data, String format,
+                                            PrintWriter outWriter) {
+
+	CDFUtils.printDataWithFormat(data, format, outWriter, 0, false);
+    }
+
+    /**
+     *  Prints the value of the given data to the place designated by
+     *  PrintWriter that can be a file, Sysem.out, System.err, and etc.  
+     *  Data can be a java primitive data type, Java Object (non-array), or 
+     *  1-dimensional array of primitive Java data type. <P>
+     *
+     *  @param data the data to be printed <P>
+     *  @param format the format specifically for the floating point data
+     *  @param outWriter the print writer to which formatted representations 
+     *                   of the object/data is printed as a text-output stream
+     *  @param which the Epoch data type data indicator
+     *               1 if CDF_EPOCH, 2 if CDF_EPOCH16 or 3 if CDF_TIME_TT2000
+     */
+    public static void printDataWithFormat (Object data, String format,
+                                            PrintWriter outWriter,
+				            int which) {
+        CDFUtils.printDataWithFormat(data, format, outWriter, which, false);
+    }
+
+    /**
+     *  Prints the value of the given data to the place designated by
+     *  PrintWriter that can be a file, Sysem.out, System.err, and etc.  
+     *  Data can be a java primitive data type, Java Object (non-array), or 
+     *  1-dimensional array of primitive Java data type. <P>
+     *
+     *  @param data the data to be printed <P>
+     *  @param format the format specifically for the floating point data
+     *  @param outWriter the print writer to which formatted representations 
+     *                   of the object/data is printed as a text-output stream
+     *  @param which the Epoch data type data indicator
+     *               1 if CDF_EPOCH, 2 if CDF_EPOCH16 or 3 if CDF_TIME_TT2000
+     *  @param iso8601 the ISO 8601 indicator for EPOCH data
+     */
+    public static void printDataWithFormat (Object data, String format,
+                                            PrintWriter outWriter,
+				            int which, boolean iso8601) {
+
+        CDFUtils.printDataWithFormat(data, format, outWriter, which, iso8601, "");
+    }
+
+    /**
+     *  Prints the value of the given data to the place designated by
+     *  PrintWriter that can be a file, Sysem.out, System.err, and etc.  
+     *  Data can be a java primitive data type, Java Object (non-array), or 
+     *  1-dimensional array of primitive Java data type. <P>
+     *
+     *  @param data the data to be printed <P>
+     *  @param format the format specifically for the floating point data
+     *  @param outWriter the print writer to which formatted representations 
+     *                   of the object/data is printed as a text-output stream
+     *  @param which the Epoch data type data indicator
+     *               1 if CDF_EPOCH, 2 if CDF_EPOCH16 or 3 if CDF_TIME_TT2000
+     *  @param iso8601 the ISO 8601 indicator for EPOCH data
+     *  @param addZ Added the passed string to the end of an ISO8601 format
+     *              string, (likely a "Z", to all CDF epoch data types, not 
+     *              just CDF_TIME_TT2000).
+     */
+    public static void printDataWithFormat (Object data, String format,
+                                            PrintWriter outWriter, int which,
+				            boolean iso8601, String addZ) {
+
+        if (format == null) {
+            CDFUtils.printData (data, outWriter, which, iso8601, addZ);
+            return;
+        }
+        String jFormat = CDFUtils.CFtoJformat(format);
+        if (jFormat == null || CDFUtils.isFloatingPadValue (data) == 1) {
+            CDFUtils.printData (data, outWriter, which, iso8601, addZ);
+            return;
+        }
+        int  i, arrayLength, jj = 1;
+        String signature = CDFUtils.getSignature(data);
+	if (which == 2) jj = 2;
+
+        if (signature.charAt(0) == '[') {
+            arrayLength = Array.getLength(data);
+            for (i=0; i < arrayLength; i=i+jj) {
+                 if (signature.charAt(1) == 'B') {
+//                   outWriter.format (jFormat+" ", Array.getByte(data,i));
+                     outWriter.print (Array.getByte(data,i)+" ");
+
+                 } else if (signature.charAt(1) == 'S') {
+//                   outWriter.format (jFormat+" ", Array.getShort(data,i));
+                     outWriter.print (Array.getShort(data,i)+" ");
+
+                 } else if (signature.charAt(1) == 'I') {
+//                   outWriter.format (jFormat+" ", Array.getInt(data,i));
+                     outWriter.print (Array.getInt(data,i)+" ");
+
+                 } else if (signature.charAt(1) == 'J') {
+                     if (which == 0) {
+//                       outWriter.format (jFormat+" ", Array.getLong(data,i));
+                         outWriter.print (Array.getLong(data,i)+" ");
+                     } else
+                       outWriter.print (CDFTT2000.encode(Array.getLong(data,i))+
+                                        addZ+" ");
+
+                 } else if (signature.charAt(1) == 'F') {
+                       float value = Array.getFloat(data,i);
+                       if (CDFUtils.isFloatingPadValue(value) == 0)
+                         outWriter.format (jFormat+" ", value);
+                       else
+                         outWriter.format (value+" ");
+
+                 } else if (signature.charAt(1) == 'D') {
+                     if (which == 1) {
+                       outWriter.print (((!iso8601)?
+                                         Epoch.encode(Array.getDouble(data,i)):
+                                         (Epoch.encode4(Array.getDouble(data,i))+
+                                          addZ))+" ");
+                     } else if (which == 2) {
+                       double[] mmm = new double[2];
+                       mmm[0] = Array.getDouble(data,i);
+                       mmm[1] = Array.getDouble(data,i+1);
+                       outWriter.print (((!iso8601)?
+                                         Epoch16.encode(mmm):
+                                         (Epoch16.encode4(mmm)+
+                                          addZ))+(arrayLength==2?"":" "));
+                     } else {
+                         double value = Array.getDouble(data,i);
+                         if (CDFUtils.isFloatingPadValue(value) == 0)
+                           outWriter.format (jFormat+" ", Array.getDouble(data,i));
+                         else
+                           outWriter.print (value+" ");
+                     }
+		 }
+            }
+        }
+        else {
+	   if (which == 1)
+	     outWriter.print ((!iso8601)?
+                               Epoch.encode(((Double)data).doubleValue()):
+                               (Epoch.encode4(((Double)data).doubleValue())+addZ));
+           else if (which == 3)
+             outWriter.print (CDFTT2000.encode(((Long)data).longValue())+addZ);
+           else {
+               if ((signature.indexOf("Float") != -1 || 
+                    signature.indexOf("Double") != -1)  &&
+                   CDFUtils.isFloatingPadValue(data) == 0)
+                 outWriter.format (jFormat+" ", data);
+               else
+                 outWriter.print (data+" ");
+           }
+	}
+    }
+
+
     /**
      *  Returns the string value of the given data.
      *  Data can be a java primitive
@@ -512,7 +863,7 @@ public class CDFUtils implements CDFConstants {
      *  data type, Java Object (non-array), or 1-dimensional array of
      *  primitive Java data type. <P>
      *
-     *  @param data the data to be parsed <P>
+     *  @param data the data to be encoded. <P>
      *  @param epochType epoch type indicator (==1 CDF_EPOCH, ==2 CDF_EPOCH16, ==0 others) <P>
      *  @return The string value of the given data/object.  <BR>
      *          If the data is an array, its elements are delimited by a space.
@@ -524,13 +875,13 @@ public class CDFUtils implements CDFConstants {
     }
 
     /**
-     *  returns the string of the value of the given data.  
+     *  Returns the string of the value of the given data.  
      *  Data can be a java primitive
      *  data type, Java Object (non-array), or 1-dimensional array of
      *  primitive Java data type. <P>
      *
-     *  @param data the data to be parsed <P>
-     *  @param separator the delimiter for array elements <P>
+     *  @param data the data to be encoded. <P>
+     *  @param separator the delimiter for array elements. <P>
      *  @return The string value of the given data/object. <BR>
      *          If the data is an array, its elements are delimited by 
      *          the user defined separator. 
@@ -542,13 +893,13 @@ public class CDFUtils implements CDFConstants {
     }
 
     /**
-     *  returns the string of the value of the given data.  
+     *  Returns the string of the value of the given data.  
      *  Data can be a java primitive
      *  data type, Java Object (non-array), or 1-dimensional array of
      *  primitive Java data type. <P>
      *
-     *  @param data the data to be parsed <P>
-     *  @param separator the delimiter for array elements <P>
+     *  @param data the data to be encoded. <P>
+     *  @param separator the delimiter for array elements. <P>
      *  @param epochType Epoch or Epoch16 data type indicator <BR>
      *         == 1 for EPOCH, == 2 for EPOCH16, == 3 for TT2000, 
      *         == 0 for other data types <P>
@@ -562,14 +913,15 @@ public class CDFUtils implements CDFConstants {
 
         return CDFUtils.getStringData(data, separator, 0, "");
     }
+
     /**
-     *  returns the string of the value of the given data.  
+     *  Returns the string of the value of the given data.  
      *  Data can be a java primitive
      *  data type, Java Object (non-array), or 1-dimensional array of
      *  primitive Java data type. <P>
      *
-     *  @param data the data to be parsed <P>
-     *  @param separator the delimiter for array elements <P>
+     *  @param data the data to be encoded. <P>
+     *  @param separator the delimiter for array elements. <P>
      *  @param epochType Epoch or Epoch16 data type indicator <BR>
      *         == 1 for EPOCH, == 2 for EPOCH16, == 3 for TT2000, 
      *         == 0 for other data types <P>
@@ -667,6 +1019,103 @@ public class CDFUtils implements CDFConstants {
         return buffer.toString();
     }
 
+    /**
+     *  Returns the string of the value of the given data.  
+     *  Data can be a java primitive data type, Java Object (non-array), or
+     *  1-dimensional array of primitive or Java data type. The data shall
+     *  be one of CDF numerical data types. The value
+     *  will be formatted in format form if it is presented.
+     *  <P>
+     *
+     *  @param data the data to be encoded. <P>
+     *  @param format the data format to be used. <P>
+     *  @param separator the delimiter for array elements. <P>
+     *  @return The string value of the given data/object. <BR>
+     *          If the data is an array, its elements are delimited by 
+     *          the user defined separator. 
+     *
+     */
+    public static String getStringFloatingData (Object data, String format,
+                                                String separator) {
+        int  i, arrayLength;
+        String signature = CDFUtils.getSignature(data);
+	StringBuffer buffer = new StringBuffer();
+
+        if (signature.charAt(0) == '[') {
+            arrayLength = Array.getLength(data);
+            for (i=0; i < arrayLength; ++i) {
+                 if (i > 0) buffer.append(separator);
+                 if (signature.charAt(1) == 'B')
+		   buffer.append(Array.getByte(data,i));
+
+                 else if (signature.charAt(1) == 'S')
+		   buffer.append(Array.getShort(data,i));
+
+                 else if (signature.charAt(1) == 'I')
+		   buffer.append(Array.getInt(data,i));
+
+                 else if (signature.charAt(1) == 'J')
+		   buffer.append(Array.getLong(data,i));
+
+                 else if (signature.charAt(1) == 'F') {
+                   float value = Array.getFloat(data,i);
+                   if (format == null ||
+                       isFloatingPadValue(value) == 1)
+                       buffer.append(value);
+                     else {
+                       format = CDFUtils.CFtoJformat (format);
+                       buffer.append(String.format(format, value));
+                     }
+
+                 } else if (signature.charAt(1) == 'D') {
+                   double value = Array.getDouble(data,i);
+                   if (format == null ||
+                       isFloatingPadValue(value) == 1)
+                       buffer.append(value);
+                     else {
+                       format = CDFUtils.CFtoJformat (format);
+                       buffer.append(String.format(format, value));
+                     }
+		 }
+	    }
+        } else {
+                 if (signature.indexOf("Byte") != -1)    
+                   buffer.append(((Byte)data).toString());
+    
+                 else if (signature.indexOf("Short") != -1)    
+                   buffer.append(((Short)data).toString());
+    
+                 else if (signature.indexOf("Integer") != -1)    
+                   buffer.append(((Integer)data).toString());
+
+                 else if (signature.indexOf("Long") != -1)
+                     buffer.append(((Long)data).toString());
+
+                 else if (signature.indexOf("Float") != -1) {
+                   float value = ((Float)data).floatValue();
+                   if (format == null ||
+                       isFloatingPadValue(value) == 1)
+                       buffer.append(value);
+                     else {
+                       format = CDFUtils.CFtoJformat (format);
+                       buffer.append(String.format(format, value));
+                     }
+
+                 } else if (signature.indexOf("Double") != -1) {
+                   double value = ((Double)data).doubleValue();
+                   if (format == null ||
+                       isFloatingPadValue(value) == 1)
+                       buffer.append(value);
+                     else {
+                       format = CDFUtils.CFtoJformat (format);
+                       buffer.append(String.format(format, value));
+                     }
+                 }
+
+	}
+        return buffer.toString();
+    }
+
     /**
      * Gets the string value of the CDF data type for the given variable. <P>
      *
@@ -1551,4 +2000,319 @@ public class CDFUtils implements CDFConstants {
        }
        return false;
     }
+
+    /**
+     *  Convert a C/Fortran-based print format to a corresponding Java style
+     *  format for numerical data. 
+     *  @param cfFormat C/Fortran-based format string <P>
+     *  @return Java style format
+     *          or null if not a valid or a non-handled C/Fortran format<BR>
+     */
+    public static String CFtoJformat (String cfFormat) {
+     
+       if (cfFormat == null) return null;
+       String format;
+       if (cfFormat.indexOf("%") != -1) format = CtoJformat (cfFormat);
+       else format = FtoJformat (cfFormat);
+       return format;
+    }
+
+    /**
+     *  Convert a Fortran-based print format to a corresponding Java style
+     *  format for numerical data. Limited Fortran format with I, F, E and G
+     *  forms.
+     *  @param fFormat Fortran-based format string <P>
+     *  @return jFormat Java style format
+     *          or null if not a valid or a non-handled Fortran format<BR>
+     */
+    public static String FtoJformat (String fFormat) {
+     
+       if (fFormat == null) return null;
+       StringBuffer sb = new StringBuffer();
+       String header = fFormat.substring(0,1).toLowerCase();
+       if (header.equals("i")) {
+         /*********************************************************************
+         * Integer/decimal.
+         *********************************************************************/
+         String format = fFormat.substring(1);
+         if (format.length() == 0) {
+           sb.append("%d");
+         } else {
+           int iPointer = format.indexOf(".");
+           if (iPointer == -1) {
+             sb.append("%").append(format).append("d");
+           } else {
+             String w = format.substring(0, iPointer);
+             String m = format.substring(iPointer+1);
+             sb.append("%").append(w).append("d");
+           }
+         }
+       } else if (header.equals("f")) {
+         /*********************************************************************
+         * Floating point/decimal form.
+         *********************************************************************/
+         String format = fFormat.substring(1);
+         if (format.length() == 0) {
+           sb.append("%f");
+         } else {
+           int iPointer = format.indexOf("."); 
+           if (iPointer == -1) {
+             return null;
+           } else {
+             String w = format.substring(0, iPointer);
+             String d = format.substring(iPointer+1);
+             sb.append("%").append(w).append(".").append(d).append("f");
+           }
+         }
+       } else if (header.equals("e") || header.equals("d")) {
+         /*********************************************************************
+         * Floating point/exponential form.
+         *********************************************************************/
+         String format = fFormat.substring(1);
+         if (format.length() == 0) {
+           sb.append("%d");
+         } else {
+           int iPointer = format.indexOf("."); 
+           if (iPointer == -1) {
+             return null;
+           } else {
+             String w = format.substring(0, iPointer);
+             String d = format.substring(iPointer+1);
+             sb.append("%").append(w).append(".").append(d).append("e");
+           }
+         }
+       } else if (header.equals("f")) {
+         /*********************************************************************
+         * Floating point/decimal form.
+         *********************************************************************/
+         String format = fFormat.substring(1);
+         if (format.length() == 0) {
+           sb.append("%d");
+         } else {
+           int iPointer = format.indexOf("."); 
+           if (iPointer == -1) {
+             return null;
+           } else {
+             String w = format.substring(0, iPointer);
+             String d = format.substring(iPointer+1);
+             sb.append("%").append(w).append(".").append(d).append("f");
+           }
+         }
+       } else if (header.equals("g")) {
+         /*********************************************************************
+         * Floating point/exponential form.
+         *********************************************************************/
+         String format = fFormat.substring(1);
+         if (format.length() == 0) {
+           sb.append("%d");
+         } else {
+           int iPointer = format.indexOf("."); 
+           if (iPointer == -1) {
+             return null;
+           } else {
+             String w = format.substring(0, iPointer);
+             String d = format.substring(iPointer+1);
+             sb.append("%").append(w).append(".").append(d).append("g");
+           }
+         }
+       }
+       if (sb.length() == 0) return null;
+       else return sb.toString();
+    }
+
+    /**
+     *  Convert a C-based print format to a corresponding Java style
+     *  format for numerical data. Limited C format with I, F, E and G
+     *  forms.
+     *  @param cFormat C-based format string <P>
+     *  @return jFormat Java style format
+     *          or null if not a valid or a non-handled Fortran format<BR>
+     */
+    public static String CtoJformat (String cFormat) {
+     
+       if (cFormat == null) return null;
+       if (cFormat.startsWith("%")) cFormat = cFormat.substring(1);
+       int num1, num2, i;
+       int len = cFormat.length();
+       int iPointer = cFormat.indexOf(".");
+       i = 0;
+       num1 = num2 = 0;
+       while (i < len && Character.isDigit(cFormat.charAt(i))) {
+         num1 = 10 * num1 + Character.getNumericValue(cFormat.charAt(i));
+         ++i;
+       }
+       if (iPointer != -1) {
+         i = iPointer + 1;
+         num2 = 0;
+         while (i < len && Character.isDigit(cFormat.charAt(i))) {
+           num2 = 10 * num2 + Character.getNumericValue(cFormat.charAt(i));
+           ++i;
+         }
+       }
+       StringBuffer sb = new StringBuffer();
+       String type = cFormat.substring(len-1).toLowerCase();
+       if (type.equals("i") || type.equals("d") || type.equals("u") ||
+           type.equals("h") || type.equals("l")) {
+         /*********************************************************************
+         * Integer/decimal.
+         *********************************************************************/
+         if (num1 == 0)
+           sb.append("%d");
+         else
+           sb.append("%").append(num1).append("d");
+       } else if (type.equals("f")) {
+         /*********************************************************************
+         * Floating point/decimal form.
+         *********************************************************************/
+         if (num1 == 0)
+           sb.append("%f");
+         else
+           if (num2 == 0)
+             sb.append("%").append(num1).append("f");
+           else
+             sb.append("%").append(num1).append(".").append(num2).append("f");
+       } else if (type.equals("e")) {
+         /*********************************************************************
+         * Floating point/exponential form.
+         *********************************************************************/
+         if (num1 == 0)
+           sb.append("%e");
+         else
+           if (num2 == 0)
+             sb.append("%").append(num1).append("e");
+           else
+             sb.append("%").append(num1).append(".").append(num2).append("e");
+       } else if (type.equals("g")) {
+         /*********************************************************************
+         * Floating point/exponential form.
+         *********************************************************************/
+         if (num1 == 0)
+           sb.append("%g");
+         else
+           if (num2 == 0)
+             sb.append("%").append(num1).append("g");
+           else
+             sb.append("%").append(num1).append(".").append(num2).append("g");
+       }
+       if (sb.length() == 0) return null;
+       else return sb.toString();
+    }
+
+    /**
+     * Check if a data is a floating point and its value is a pad value. 
+     *  @param dataType The data type of the data <P>
+     *  @param value    A single data object <P>
+     *  @return 1 if the data is of floating point and it is a pad value
+     *          0 otherwise<BR>
+     */
+
+    public static int isFloatingPadValue (long dataType, Object value) {
+
+        if (dataType == CDF_REAL4 || dataType == CDF_FLOAT) {
+          if (((Float)value).floatValue() <= DEFAULT_FLOAT_PADVALUE ||
+              ((Float)value).floatValue() >= -DEFAULT_FLOAT_PADVALUE) return 1;
+          else return 0;
+        } else if (dataType == CDF_REAL8 || dataType == CDF_DOUBLE) {
+          if (((Double)value).doubleValue() <= DEFAULT_DOUBLE_PADVALUE ||
+              ((Double)value).doubleValue() >= -DEFAULT_DOUBLE_PADVALUE) return 1;
+          else return 0;
+        } else
+          return 0;
+    }
+
+    /**
+     * Check if a data is a floating point and its value is a pad value. 
+     *  @param value    A data object <P>
+     *  @return 1 if the data is of floating point and it is a pad value
+     *          0 otherwise<BR>
+     */
+
+    public static int isFloatingPadValue (Object value) {
+
+        String signature = CDFUtils.getSignature(value);
+        if (signature.charAt(0) == '[') {
+            if (signature.charAt(1) == 'F')
+               return CDFUtils.isFloatingPadValue (Array.getFloat(value, 0));
+            else if (signature.charAt(1) == 'D')
+               return CDFUtils.isFloatingPadValue (Array.getDouble(value, 0));
+            else
+               return 0;
+        }
+
+        if (value instanceof Float) {
+          if (((Float)value).floatValue() <= DEFAULT_FLOAT_PADVALUE ||
+              ((Float)value).floatValue() >= -DEFAULT_FLOAT_PADVALUE) return 1;
+          else return 0;
+        } else if (value instanceof Double) {
+          if (((Double)value).doubleValue() <= DEFAULT_DOUBLE_PADVALUE ||
+              ((Double)value).doubleValue() >= -DEFAULT_DOUBLE_PADVALUE) return 1;
+          else return 0;
+        } else
+          return 0;
+    }
+
+    /**
+     * Check if a data is a floating point and its value is a pad value. 
+     *  @param dataType The data type of the data <P>
+     *  @param value    The float data <P>
+     *  @return 1 if the data is of floating point and it is a pad value
+     *          0 otherwise<BR>
+     */ 
+
+    public static int isFloatingPadValue (long dataType, float value) {
+
+        if (dataType == CDF_REAL4 || dataType == CDF_FLOAT) {
+          if (value <= DEFAULT_FLOAT_PADVALUE ||
+              value >= -DEFAULT_FLOAT_PADVALUE) return 1;
+          else return 0;
+        } else
+          return 0;
+    }
+
+    /**
+     * Check if a data is a floating point and its value is a pad value. 
+     *  @param dataType The data type of the data <P>
+     *  @param value    The double data <P>
+     *  @return 1 if the data is of floating point and it is a pad value
+     *          0 otherwise<BR>
+     */
+
+    public static int isFloatingPadValue (long dataType, double value) {
+          
+        if (dataType == CDF_REAL8 || dataType == CDF_DOUBLE) {
+          if (value <= DEFAULT_DOUBLE_PADVALUE ||
+              value >= -DEFAULT_DOUBLE_PADVALUE) return 1;
+          else return 0;
+        } else
+          return 0;
+    }
+
+    /**
+     * Check if a float data is a pad value. 
+     *  @param value    a float data <P>
+     *  @return 1 if the data is a pad value
+     *          0 otherwise<BR>
+     */ 
+
+    public static int isFloatingPadValue (float value) {
+
+        if (value <= DEFAULT_FLOAT_PADVALUE ||
+            value >= -DEFAULT_FLOAT_PADVALUE) return 1;
+        else return 0;
+    }
+
+    /**
+     * Check if a double data is a pad value. 
+     *  @param value    a double data <P>
+     *  @return 1 if the data is a pad value
+     *          0 otherwise<BR>
+     */
+
+    public static int isFloatingPadValue (double value) {
+          
+        if (value <= DEFAULT_DOUBLE_PADVALUE ||
+            value >= -DEFAULT_DOUBLE_PADVALUE) return 1;
+        else return 0;
+    }
+
 }
