@@ -1,4 +1,4 @@
-// $Id: Epoch.java,v 1.16 2019/04/11 14:04:26 mhliu Exp $
+// $Id: Epoch.java,v 1.3 2020/06/24 18:30:23 mhliu Exp $
 /*
  * Copyright 1996-2014 United States Government as represented by the
  * Administrator of the National Aeronautics and Space Administration.
@@ -1693,7 +1693,7 @@ public class Epoch implements gsfc.nssdc.cdf.CDFConstants {
     {
 	long [] components = new long[7];
 	long jd,i,j,k,l,n;
-	double msec_AD, second_AD, minute_AD, hour_AD, day_AD;
+	long msec_AD, second_AD, minute_AD, hour_AD, day_AD;
 	
 	if (epoch == -1.0E31) {
 	  components[0] = 9999;
@@ -1709,11 +1709,11 @@ public class Epoch implements gsfc.nssdc.cdf.CDFConstants {
 	if (epoch < 0.0) epoch = -epoch;
 	epoch = (MAX_EPOCH_BINARY < epoch ? MAX_EPOCH_BINARY : epoch);
 
-	msec_AD = epoch;
-	second_AD = msec_AD / 1000.0;
-	minute_AD = second_AD / 60.0;
-	hour_AD = minute_AD / 60.0;
-	day_AD = hour_AD / 24.0;
+	msec_AD = (long) epoch;
+	second_AD = msec_AD / 1000;
+	minute_AD = second_AD / 60;
+	hour_AD = minute_AD / 60;
+	day_AD = hour_AD / 24;
 	
 	jd = (long) (1721060 + day_AD);
 	l=jd+68569;
@@ -1731,10 +1731,10 @@ public class Epoch implements gsfc.nssdc.cdf.CDFConstants {
 	components[1] = j;
 	components[2] = k;
 	
-	components[3] = (long) (hour_AD   % (double) 24.0);
-	components[4] = (long) (minute_AD % (double) 60.0);
-	components[5] = (long) (second_AD % (double) 60.0);
-	components[6] = (long) (msec_AD   % (double) 1000.0);
+	components[3] = (long) ((double) hour_AD   % (double) 24.0);
+	components[4] = (long) ((double) minute_AD % (double) 60.0);
+	components[5] = (long) ((double) second_AD % (double) 60.0);
+	components[6] = (long) ((double) msec_AD   % (double) 1000.0);
 	
 	return components;
     }
