@@ -1,4 +1,4 @@
-// $Id: Epoch16.java,v 1.17 2019/04/11 14:04:26 mhliu Exp $
+// $Id: Epoch16.java,v 1.3 2020/06/24 18:33:13 mhliu Exp $
 /*
  * Copyright 1996-2014 United States Government as represented by the
  * Administrator of the National Aeronautics and Space Administration.
@@ -1158,7 +1158,8 @@ public class Epoch16 implements gsfc.nssdc.cdf.CDFConstants {
     {
 	long [] components = new long[10];
 	long jd,i,j,k,l,n;
-	double msec, second_AD, minute_AD, hour_AD, day_AD;
+	double msec;
+        long second_AD, minute_AD, hour_AD, day_AD;
 	double[] epoch16 = new double[2];
 	
 	epoch16[0] = ((double[]) epoch)[0];
@@ -1192,10 +1193,10 @@ public class Epoch16 implements gsfc.nssdc.cdf.CDFConstants {
                                          (MAX_EPOCH16_2_BINARY+1.0) :
                                          epoch16[1]);
 
-	second_AD = epoch16[0];
-	minute_AD = second_AD / 60.0;
-	hour_AD = minute_AD / 60.0;
-	day_AD = hour_AD / 24.0;
+	second_AD = (long) epoch16[0];
+	minute_AD = second_AD / 60;
+	hour_AD = minute_AD / 60;
+	day_AD = hour_AD / 24;
 	
 	jd = (long) (1721060 + day_AD);
 	l=jd+68569;
@@ -1213,9 +1214,9 @@ public class Epoch16 implements gsfc.nssdc.cdf.CDFConstants {
 	components[1] = j;
 	components[2] = k;
 	
-	components[3] = (long) (hour_AD   % (double) 24.0);
-	components[4] = (long) (minute_AD % (double) 60.0);
-	components[5] = (long) (second_AD % (double) 60.0);
+	components[3] = (long) ((double) hour_AD   % (double) 24.0);
+	components[4] = (long) ((double) minute_AD % (double) 60.0);
+	components[5] = (long) ((double) second_AD % (double) 60.0);
 
 	msec = epoch16[1];
         components[9] = (long) (msec % (double) 1000.0);
